@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -105,6 +77,10 @@ import com.openexchange.log.audit.DefaultAttribute;
 import com.openexchange.log.audit.DefaultAttribute.Name;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.api.AuthType;
+import com.openexchange.mail.api.IMailFolderStorage;
+import com.openexchange.mail.api.IMailFolderStorageDelegator;
+import com.openexchange.mail.api.IMailMessageStorage;
+import com.openexchange.mail.api.IMailMessageStorageDelegator;
 import com.openexchange.mail.api.IMailProperties;
 import com.openexchange.mail.api.IMailStoreAware;
 import com.openexchange.mail.api.MailAccess;
@@ -123,6 +99,7 @@ import com.openexchange.net.ssl.exception.SSLExceptionCode;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.session.Session;
 import com.openexchange.session.Sessions;
+import com.openexchange.systemproperties.SystemPropertiesUtils;
 import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.timer.ScheduledTimerTask;
@@ -217,6 +194,59 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         return b.booleanValue();
     }
 
+    /**
+     * Gets the IMAP folder storage from given connected mail access if IMAP-backed.
+     *
+     * @param mailAccess The connected mail access
+     * @return The IMAP folder storage
+     * @throws OXException If IMAP folder storage cannot be returned
+     */
+    public static IMAPFolderStorage getIMAPFolderStorageFrom(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws OXException {
+        IMailFolderStorage fstore = mailAccess.getFolderStorage();
+        if (!(fstore instanceof IMAPFolderStorage)) {
+            if (!(fstore instanceof IMailFolderStorageDelegator)) {
+                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+            }
+            fstore = ((IMailFolderStorageDelegator) fstore).getDelegateFolderStorage();
+            if (!(fstore instanceof IMAPFolderStorage)) {
+                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+            }
+        }
+        return (IMAPFolderStorage) fstore;
+    }
+
+    /**
+     * Gets the IMAP store from given connected mail access if IMAP-backed.
+     *
+     * @param mailAccess The connected mail access
+     * @return The IMAP store
+     * @throws OXException If IMAP store cannot be returned
+     */
+    public static IMAPStore getIMAPStoreFrom(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws OXException {
+        return getIMAPFolderStorageFrom(mailAccess).getImapStore();
+    }
+
+    /**
+     * Gets the connected {@link IMAPMessageStorage} instance associated with specified mail access
+     *
+     * @param mailAccess The connected mail access
+     * @return The connected {@code IMAPMessageStorage} instance
+     * @throws OXException If connected {@code IMAPMessageStorage} instance cannot be returned
+     */
+    public static IMAPMessageStorage getImapMessageStorageFrom(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws OXException {
+        IMailMessageStorage mstore = mailAccess.getMessageStorage();
+        if (!(mstore instanceof IMAPMessageStorage)) {
+            if (!(mstore instanceof IMailMessageStorageDelegator)) {
+                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+            }
+            mstore = ((IMailMessageStorageDelegator) mstore).getDelegateMessageStorage();
+            if (!(mstore instanceof IMAPMessageStorage)) {
+                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+            }
+        }
+        return (IMAPMessageStorage) mstore;
+    }
+
     /*-
      * Member section
      */
@@ -266,6 +296,11 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      */
     private int port;
 
+    /**
+     * Whether to establish a direct SSL connection.
+     */
+    private boolean secure;
+
     /**
      * The user's login name.
      */
@@ -291,9 +326,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      *
      * @param session The session providing needed user data
      */
-    protected IMAPAccess(final Session session) {
+    protected IMAPAccess(Session session) {
         super(session);
-        setMailProperties((Properties) System.getProperties().clone());
+        setMailProperties(SystemPropertiesUtils.cloneSystemProperties());
     }
 
     /**
@@ -302,9 +337,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      * @param session The session providing needed user data
      * @param accountId The account ID
      */
-    protected IMAPAccess(final Session session, final int accountId) {
+    protected IMAPAccess(Session session, int accountId) {
         super(session, accountId);
-        setMailProperties((Properties) System.getProperties().clone());
+        setMailProperties(SystemPropertiesUtils.cloneSystemProperties());
     }
 
     @Override
@@ -426,6 +461,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 this.imapStore = null;
             }
         } finally {
+            LogProperties.remove(LogProperties.Name.MAIL_HOST_REMOTE_ADDRESS);
             reset();
         }
     }
@@ -494,7 +530,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
     }
 
     @Override
-    public int getUnreadMessagesCount(final String fullname) throws OXException {
+    public int getUnreadMessagesCount(String fullname) throws OXException {
         if (!isConnected()) {
             connect(false);
         }
@@ -517,7 +553,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             }
             final Set<String> attrs = listEntry.getAttributes();
             if (null != attrs) {
-                for (final String attribute : attrs) {
+                for (String attribute : attrs) {
                     if ("\\NonExistent".equalsIgnoreCase(attribute)) {
                         throw IMAPException.create(IMAPException.Code.FOLDER_NOT_FOUND, imapConfig, session, fullname);
                     }
@@ -557,7 +593,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              * Try to connect to IMAP server
              */
             final IIMAPProperties imapConfProps = (IIMAPProperties) config.getMailProperties();
-            String tmpPass = getMailConfig().getPassword();
+            String tmpPass = config.getPassword();
             String login = config.getLogin();
             /*
              * Get properties
@@ -579,7 +615,8 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              */
             String server = IDNA.toASCII(config.getServer());
             int port = config.getPort();
-            if (Boolean.parseBoolean(imapSession.getProperty(MimeSessionPropertyNames.PROP_MAIL_DEBUG))) {
+            if (debug || Boolean.parseBoolean(imapSession.getProperty(MimeSessionPropertyNames.PROP_MAIL_DEBUG))) {
+                // imapSession.setDebugOut(DevNullPrintStream.getInstance()); // Swallow superfluous JavaMail debug logging: "setDebug: JavaMail version x.y.z"
                 imapSession.setDebug(true);
                 imapSession.setDebugOut(System.err);
             } else if (PropUtil.getBooleanProperty(imapSession.getProperties(), "mail.imap.debugLog.enabled", false)) {
@@ -595,7 +632,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 /*
                  * Get connected store
                  */
-                imapStore = newConnectedImapStore(imapSession, server, port, login, tmpPass, -1, preAuthStartTlsCap, true);
+                imapStore = newConnectedImapStore(imapSession, server, port, config.isSecure(), login, tmpPass, -1, preAuthStartTlsCap, true);
                 /*
                  * Add warning if non-secure
                  */
@@ -712,6 +749,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     imapProps.put("mail.imap.sasl.mechanisms", "PLAIN");
                 }
             }
+
             /*
              * Get parameterized IMAP session
              */
@@ -735,13 +773,15 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              */
             this.server = IDNA.toASCII(config.getServer());
             this.port = config.getPort();
+            this.secure = config.isSecure();
             this.login = isProxyAuth ? proxyUser : user;
             this.password = tmpPassword;
             /*
              * Check if debug should be enabled
              */
             final boolean certainUser = false;
-            if (certainUser || Boolean.parseBoolean(imapSession.getProperty(MimeSessionPropertyNames.PROP_MAIL_DEBUG))) {
+            if (certainUser || debug || Boolean.parseBoolean(imapSession.getProperty(MimeSessionPropertyNames.PROP_MAIL_DEBUG))) {
+                // imapSession.setDebugOut(DevNullPrintStream.getInstance()); // Swallow superfluous JavaMail debug logging: "setDebug: JavaMail version x.y.z"
                 imapSession.setDebug(true);
                 imapSession.setDebugOut(System.out);
             } else if (PropUtil.getBooleanProperty(imapSession.getProperties(), "mail.imap.debugLog.enabled", false)) {
@@ -880,7 +920,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         }
     }
 
-    private boolean isPropagateAccount(final IIMAPProperties imapConfProps) throws OXException {
+    private boolean isPropagateAccount(IIMAPProperties imapConfProps) throws OXException {
         if (MailAccount.DEFAULT_ID == accountId) {
             return true;
         }
@@ -901,13 +941,13 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If another error occurs
      */
-    public IMAPStore connectIMAPStore(final int maxCount) throws MessagingException, OXException {
-        return connectIMAPStore(maxCount, imapSession, server, port, login, password, clientIp);
+    public IMAPStore connectIMAPStore(int maxCount) throws MessagingException, OXException {
+        return connectIMAPStore(maxCount, imapSession, server, port, secure, login, password, clientIp);
     }
 
     private static final String PROTOCOL = IMAPProvider.PROTOCOL_IMAP.getName();
 
-    private IMAPStore connectIMAPStore(final int maxCount, final javax.mail.Session imapSession, final String server, final int port, final String login, final String pw, final String clientIp) throws MessagingException, OXException {
+    private IMAPStore connectIMAPStore(int maxCount, javax.mail.Session imapSession, String server, int port, boolean secure, String login, String pw, String clientIp) throws MessagingException, OXException {
         /*
          * Propagate client IP address
          */
@@ -960,7 +1000,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         int retryCount = 0;
         while (retryCount++ < maxRetryCount) {
             try {
-                return newConnectedImapStore(imapSession, server, port, login, pw, accountId);
+                return newConnectedImapStore(imapSession, server, port, secure, login, pw, accountId);
             } catch (MessagingException e) {
                 if (!(e.getNextException() instanceof ConnectQuotaExceededException)) {
                     throw e;
@@ -973,11 +1013,11 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         throw new MessagingException("Unable to connect to IMAP store: " + new URLName("imap", server, port, null, config.getLogin(), "xxxx"));
     }
 
-    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, String login, String pw, int accountId) throws MessagingException {
-        return newConnectedImapStore(imapSession, server, port, login, pw, accountId, null, false);
+    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, boolean secure, String login, String pw, int accountId) throws MessagingException {
+        return newConnectedImapStore(imapSession, server, port, secure, login, pw, accountId, null, false);
     }
 
-    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, String login, String pw, int accountId, boolean[] preAuthStartTlsCap, boolean knownExternal) throws MessagingException {
+    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, boolean secure, String login, String pw, int accountId, boolean[] preAuthStartTlsCap, boolean knownExternal) throws MessagingException {
         /*
          * Establish a new one...
          */
@@ -1002,7 +1042,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          */
         if (null != preAuthStartTlsCap) {
             try {
-                Map<String, String> capabilities = IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(server), port), false, IMAPProperties.getInstance(), isPrimary);
+                Map<String, String> capabilities = IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(server), port), secure, IMAPProperties.getInstance(), isPrimary);
                 if (null != capabilities) {
                     preAuthStartTlsCap[0] = capabilities.containsKey("STARTTLS");
                 }
@@ -1043,6 +1083,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     imapStore.connect(server, port, login, pw);
                 }
             }
+            //new Throwable("New IMAP connection").printStackTrace(System.out);
             AuditLogService auditLogService = Services.optService(AuditLogService.class);
             if (null != auditLogService) {
                 String eventId = knownExternal ? "imap.external.login" : (MailAccount.DEFAULT_ID == accountId ? "imap.primary.login" : "imap.external.login");
@@ -1218,13 +1259,13 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                         /*
                          * Clean-up temporary-down map
                          */
-                        for (final Iterator<Entry<HostAndPort, Long>> iter = map1.entrySet().iterator(); iter.hasNext();) {
+                        for (Iterator<Entry<HostAndPort, Long>> iter = map1.entrySet().iterator(); iter.hasNext();) {
                             final Entry<HostAndPort, Long> entry = iter.next();
                             if (System.currentTimeMillis() - entry.getValue().longValue() > MAX_TEMP_DOWN) {
                                 iter.remove();
                             }
                         }
-                        for (final Iterator<Entry<HostAndPortAndCredentials, StampAndOXException>> iter = map2.entrySet().iterator(); iter.hasNext();) {
+                        for (Iterator<Entry<HostAndPortAndCredentials, StampAndOXException>> iter = map2.entrySet().iterator(); iter.hasNext();) {
                             final Entry<HostAndPortAndCredentials, StampAndOXException> entry = iter.next();
                             if (System.currentTimeMillis() - entry.getValue().getStamp() > MAX_TEMP_DOWN) {
                                 iter.remove();
@@ -1526,7 +1567,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      *
      * @param imapStore The IMAP store to close
      */
-    public static void closeSafely(final IMAPStore imapStore) {
+    public static void closeSafely(IMAPStore imapStore) {
         if (null != imapStore) {
             try {
                 imapStore.close();
