@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -200,7 +172,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasACL;
     }
 
-    public void setACL(final boolean hasACL) {
+    public void setACL(boolean hasACL) {
         this.hasACL = hasACL;
     }
 
@@ -208,7 +180,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasIMAP4;
     }
 
-    public void setIMAP4(final boolean hasIMAP4) {
+    public void setIMAP4(boolean hasIMAP4) {
         this.hasIMAP4 = hasIMAP4;
     }
 
@@ -216,7 +188,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasIMAP4rev1;
     }
 
-    public void setIMAP4rev1(final boolean hasIMAP4rev1) {
+    public void setIMAP4rev1(boolean hasIMAP4rev1) {
         this.hasIMAP4rev1 = hasIMAP4rev1;
     }
 
@@ -225,7 +197,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasQuota;
     }
 
-    public void setQuota(final boolean hasQuota) {
+    public void setQuota(boolean hasQuota) {
         this.hasQuota = hasQuota;
     }
 
@@ -234,7 +206,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasSort;
     }
 
-    public void setSort(final boolean hasSort) {
+    public void setSort(boolean hasSort) {
         this.hasSort = hasSort;
     }
 
@@ -242,7 +214,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasThreadOrderedSubject;
     }
 
-    public void setThreadOrderedSubject(final boolean hasThreadOrderedSubject) {
+    public void setThreadOrderedSubject(boolean hasThreadOrderedSubject) {
         this.hasThreadOrderedSubject = hasThreadOrderedSubject;
     }
 
@@ -251,7 +223,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasThreadReferences;
     }
 
-    public void setThreadReferences(final boolean hasThreadReferences) {
+    public void setThreadReferences(boolean hasThreadReferences) {
         this.hasThreadReferences = hasThreadReferences;
     }
 
@@ -259,7 +231,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasUIDPlus;
     }
 
-    public void setUIDPlus(final boolean hasUIDPlus) {
+    public void setUIDPlus(boolean hasUIDPlus) {
         this.hasUIDPlus = hasUIDPlus;
     }
 
@@ -268,7 +240,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasSubscription;
     }
 
-    public void setHasSubscription(final boolean hasSubscription) {
+    public void setHasSubscription(boolean hasSubscription) {
         this.hasSubscription = hasSubscription;
     }
 
@@ -276,7 +248,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasNamespace;
     }
 
-    public void setNamespace(final boolean hasNamespace) {
+    public void setNamespace(boolean hasNamespace) {
         this.hasNamespace = hasNamespace;
     }
 
@@ -284,7 +256,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasIdle;
     }
 
-    public void setIdle(final boolean hasIdle) {
+    public void setIdle(boolean hasIdle) {
         this.hasIdle = hasIdle;
     }
 
@@ -292,7 +264,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasChildren;
     }
 
-    public void setChildren(final boolean hasChildren) {
+    public void setChildren(boolean hasChildren) {
         this.hasChildren = hasChildren;
     }
 
@@ -300,7 +272,7 @@ public class IMAPCapabilities extends MailCapabilities {
         return hasSortDisplay;
     }
 
-    public void setSortDisplay(final boolean hasSortDisplay) {
+    public void setSortDisplay(boolean hasSortDisplay) {
         this.hasSortDisplay = hasSortDisplay;
     }
 
