@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -201,7 +173,7 @@ public final class IMAPConversationWorker {
 
             @SuppressWarnings("synthetic-access")
             @Override
-            public void reloadConfiguration(final ConfigurationService configService) {
+            public void reloadConfiguration(ConfigurationService configService) {
                 useImapThreaderIfSupported = null;
             }
 
@@ -254,7 +226,7 @@ public final class IMAPConversationWorker {
      * @return The message conversations
      * @throws OXException If message conversations cannot be returned
      */
-    public List<List<MailMessage>> getThreadSortedMessages(final String fullName, final boolean includeSent, @SuppressWarnings("unused") final boolean cache, final IndexRange indexRange, final long max, final MailSortField sortField, final OrderDirection order, final MailField[] mailFields, String[] headerNames, SearchTerm<?> searchTerm) throws OXException {
+    public List<List<MailMessage>> getThreadSortedMessages(String fullName, boolean includeSent, @SuppressWarnings("unused") final boolean cache, IndexRange indexRange, long max, MailSortField sortField, OrderDirection order, MailField[] mailFields, String[] headerNames, SearchTerm<?> searchTerm) throws OXException {
         IMAPFolder sentFolder = null;
         try {
             final String sentFullName = imapFolderStorage.getSentFolder();
@@ -309,7 +281,7 @@ public final class IMAPConversationWorker {
 
     private static final MailFields FIELDS_FLAGS = new MailFields(MailField.FLAGS, MailField.COLOR_LABEL);
 
-    private List<List<MailMessage>> doReferenceOnlyThreadSort(final String fullName, IndexRange indexRange, MailSortField sortField, OrderDirection order, final String sentFullName, int lookAhead, final boolean mergeWithSent, MailField[] mailFields, final String[] headerNames, SearchTerm<?> searchTerm) throws MessagingException, OXException {
+    private List<List<MailMessage>> doReferenceOnlyThreadSort(String fullName, IndexRange indexRange, MailSortField sortField, OrderDirection order, String sentFullName, int lookAhead, boolean mergeWithSent, MailField[] mailFields, String[] headerNames, SearchTerm<?> searchTerm) throws MessagingException, OXException {
         boolean useSearchTerm = searchTerm != null;
         final MailFields usedFields = new MailFields(mailFields);
         // add necessary fields for searchTerm
@@ -421,7 +393,7 @@ public final class IMAPConversationWorker {
                     // Filter messages already contained in conversations
                     {
                         Set<String> allMessageIds = new HashSet<>(conversations.size());
-                        for (final Conversation conversation : conversations) {
+                        for (Conversation conversation : conversations) {
                             conversation.addMessageIdsTo(allMessageIds);
                         }
                         for (Iterator<MailMessage> iter = sentMessages.iterator(); iter.hasNext();) {
@@ -450,7 +422,7 @@ public final class IMAPConversationWorker {
         MailMessageComparator threadComparator = COMPARATOR_DESC;
         // Sort
         final List<List<MailMessage>> list = new ArrayList<>(conversations.size());
-        for (final Conversation conversation : conversations) {
+        for (Conversation conversation : conversations) {
             list.add(conversation.getMessages(threadComparator));
         }
         conversations = null;
@@ -778,7 +750,7 @@ public final class IMAPConversationWorker {
                     // Filter messages already contained in conversations
                     {
                         Set<String> allMessageIds = new HashSet<>(conversations.size());
-                        for (final Conversation conversation : conversations) {
+                        for (Conversation conversation : conversations) {
                             conversation.addMessageIdsTo(allMessageIds);
                         }
                         for (Iterator<MailMessage> iter = sentMessages.iterator(); iter.hasNext();) {
@@ -802,7 +774,7 @@ public final class IMAPConversationWorker {
             final MailMessageComparator threadComparator = COMPARATOR_DESC;
             // Sort
             list = new LinkedList<>();
-            for (final Conversation conversation : conversations) {
+            for (Conversation conversation : conversations) {
                 list.add(conversation.getMessages(threadComparator));
             }
             conversations = null;
@@ -896,7 +868,7 @@ public final class IMAPConversationWorker {
         return list;
     }
 
-    private String getSortRange(int lookAhead, final int messageCount, final OrderDirection order) {
+    private String getSortRange(int lookAhead, int messageCount, OrderDirection order) {
         final String sortRange;
         if (lookAhead <= 0) {
             sortRange = "ALL";
@@ -910,12 +882,12 @@ public final class IMAPConversationWorker {
         return sortRange;
     }
 
-    private Comparator<List<MailMessage>> getListComparator(final MailSortField sortField, final OrderDirection order, final String fullName, final Locale locale) {
+    private Comparator<List<MailMessage>> getListComparator(MailSortField sortField, OrderDirection order, String fullName, Locale locale) {
         final MailMessageComparator comparator = MailMessageComparatorFactory.createComparator(sortField, order, locale, imapFolderStorage.getSession(), imapFolderStorage.getImapConfig().getIMAPProperties().isUserFlagsEnabled());
         Comparator<List<MailMessage>> listComparator = new Comparator<List<MailMessage>>() {
 
             @Override
-            public int compare(final List<MailMessage> o1, final List<MailMessage> o2) {
+            public int compare(List<MailMessage> o1, List<MailMessage> o2) {
                 MailMessage msg1 = lookUpFirstBelongingToFolder(fullName, o1);
                 MailMessage msg2 = lookUpFirstBelongingToFolder(fullName, o2);
 
@@ -1147,7 +1119,7 @@ public final class IMAPConversationWorker {
         return mailThreads;
     }
 
-    private Comparator<MailThread> getThreadComparator(final MailSortField sortField, final OrderDirection order, Locale locale) {
+    private Comparator<MailThread> getThreadComparator(MailSortField sortField, OrderDirection order, Locale locale) {
         final MailMessageComparator comparator = MailMessageComparatorFactory.createComparator(sortField, order, locale, imapFolderStorage.getSession(), imapFolderStorage.getImapConfig().getIMAPProperties().isUserFlagsEnabled());
         Comparator<MailThread> threadComparator = new Comparator<MailThread>() {
 
@@ -1177,7 +1149,7 @@ public final class IMAPConversationWorker {
 
     // -----------------------------------------------------------------------------------------------------------------------------------
 
-    public MailMessage[] getThreadSortedMessages(final String fullName, final IndexRange indexRange, final MailSortField sortField, final OrderDirection order, final SearchTerm<?> searchTerm, final MailField[] mailFields) throws OXException {
+    public MailMessage[] getThreadSortedMessages(String fullName, IndexRange indexRange, MailSortField sortField, OrderDirection order, SearchTerm<?> searchTerm, MailField[] mailFields) throws OXException {
         try {
             imapMessageStorage.openReadOnly(fullName);
             if (0 >= imapMessageStorage.getImapFolder().getMessageCount()) {
@@ -1243,7 +1215,7 @@ public final class IMAPConversationWorker {
             }
             final List<MessageInfo> messageIds = ThreadSortUtil.fromThreadResponse(threadList);
             final TIntObjectMap<MessageInfo> seqNum2MessageId = new TIntObjectHashMap<>(messageIds.size());
-            for (final MessageInfo messageId : messageIds) {
+            for (MessageInfo messageId : messageIds) {
                 seqNum2MessageId.put(messageId.getMessageNumber(), messageId);
             }
             /*
@@ -1268,7 +1240,7 @@ public final class IMAPConversationWorker {
                     messages.forEachEntry(new TLongObjectProcedure<MailMessage>() {
 
                         @Override
-                        public boolean execute(final long seqNum, final MailMessage m) {
+                        public boolean execute(long seqNum, MailMessage m) {
                             mapping.put(seqNum2MessageId.get((int) seqNum), m);
                             return true;
                         }
@@ -1285,7 +1257,7 @@ public final class IMAPConversationWorker {
                  */
                 List<MailMessage> flatList = new LinkedList<>();
                 if (usedFields.contains(MailField.ACCOUNT_NAME) || usedFields.contains(MailField.FULL)) {
-                    for (final MailMessage mail : flatList) {
+                    for (MailMessage mail : flatList) {
                         imapMessageStorage.setAccountInfo(mail);
                     }
                 }
@@ -1377,7 +1349,7 @@ public final class IMAPConversationWorker {
         }
     }
 
-    private static int applyThreadLevel(final List<ThreadSortNode> threadList, final int level, final Message[] msgs, final int index) {
+    private static int applyThreadLevel(List<ThreadSortNode> threadList, int level, Message[] msgs, int index) {
         if (null == threadList) {
             return index;
         }
