@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -109,7 +81,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         final MessagingException error;
         final long stamp;
 
-        FailFastError(final MessagingException e) {
+        FailFastError(MessagingException e) {
             super();
             this.error = e;
             this.stamp = System.currentTimeMillis();
@@ -139,7 +111,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
 
             @SuppressWarnings("synthetic-access")
             @Override
-            public void reloadConfiguration(final ConfigurationService configService) {
+            public void reloadConfiguration(ConfigurationService configService) {
                 failFastTimeout = null;
             }
 
@@ -214,7 +186,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      * @param session The session providing needed user data
      * @throws OXException If context lading fails
      */
-    protected IMAPFolderWorker(final IMAPStore imapStore, final IMAPAccess imapAccess, final Session session) throws OXException {
+    protected IMAPFolderWorker(IMAPStore imapStore, IMAPAccess imapAccess, Session session) throws OXException {
         super();
         this.imapStore = imapStore;
         this.imapAccess = imapAccess;
@@ -311,7 +283,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      *
      * @param modifiedFullName The full name of the folder which has been modified
      */
-    public void notifyIMAPFolderModification(final String modifiedFullName) {
+    public void notifyIMAPFolderModification(String modifiedFullName) {
         if ((null == imapFolder) || !modifiedFullName.equals(imapFolder.getFullName())) {
             /*
              * Modified folder did not affect remembered IMAP folder
@@ -332,7 +304,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      *
      * @param modifiedFullNames The full names of the folders which have been modified
      */
-    public void notifyIMAPFolderModification(final Set<String> modifiedFullNames) {
+    public void notifyIMAPFolderModification(Set<String> modifiedFullNames) {
         if ((null == imapFolder) || !modifiedFullNames.contains(imapFolder.getFullName())) {
             /*
              * Modified folders did not affect remembered IMAP folder
@@ -351,7 +323,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      *
      * @param folder The IMAP folder to add
      */
-    protected void addOpenedFolder(final IMAPFolder folder) {
+    protected void addOpenedFolder(IMAPFolder folder) {
         if (null == folder) {
             return;
         }
@@ -378,7 +350,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
     }
 
     private void closeOtherFolders() {
-        for (final IMAPFolder f : otherFolders) {
+        for (IMAPFolder f : otherFolders) {
             try {
                 f.close(false);
             } catch (Exception e) {
@@ -425,7 +397,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If user does not hold sufficient rights to open the IMAP folder in desired mode
      */
-    protected final IMAPFolder setAndOpenFolder(final String fullName, final int desiredMode) throws MessagingException, OXException {
+    protected final IMAPFolder setAndOpenFolder(String fullName, int desiredMode) throws MessagingException, OXException {
         return setAndOpenFolder(null, fullName, desiredMode);
     }
 
@@ -441,7 +413,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If user does not hold sufficient rights to open the IMAP folder in desired mode
      */
-    protected final IMAPFolder setAndOpenFolder(final IMAPFolder imapFolder, final String fullName, final int desiredMode) throws MessagingException, OXException {
+    protected final IMAPFolder setAndOpenFolder(IMAPFolder imapFolder, String fullName, int desiredMode) throws MessagingException, OXException {
         if (null == fullName) {
             throw MailExceptionCode.MISSING_FULLNAME.create();
         }
@@ -473,6 +445,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                         if (isEqualFolder && (mode >= desiredMode)) {
                             // Identical folder is already opened in an appropriate mode.
                             close = false;
+                            IMAPCommandsCollection.noopCommand(imapFolder);
                             return imapFolder;
                         }
 
@@ -596,7 +569,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      * @param e The runtime exception to handle
      * @return An appropriate {@link OXException}
      */
-    protected OXException handleRuntimeException(final RuntimeException e) {
+    protected OXException handleRuntimeException(RuntimeException e) {
         if (e instanceof ListLsubRuntimeException) {
             ListLsubCache.clearCache(accountId, session);
             return MailExceptionCode.INTERRUPT_ERROR.create(e, e.getMessage());
@@ -609,7 +582,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      *
      * @param imapFolder The IMAP folder
      */
-    public static void clearCache(final IMAPFolder imapFolder) {
+    public static void clearCache(IMAPFolder imapFolder) {
         if (null == imapFolder) {
             return;
         }
@@ -617,7 +590,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
     }
 
     /** Safely clears the cache */
-    protected static void clearCacheSafe(final IMAPFolder imapFolder) {
+    protected static void clearCacheSafe(IMAPFolder imapFolder) {
         try {
             clearCache(imapFolder);
         } catch (Exception e) {
