@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -73,7 +45,7 @@ public class NamespaceFolder extends IMAPFolder {
      * @param name The folder's name
      * @param separator The folder's separator
      */
-    public NamespaceFolder(final IMAPStore store, final String name, final char separator) {
+    public NamespaceFolder(IMAPStore store, String name, char separator) {
         super(name, separator, store, Boolean.TRUE);
         exists = true; // of course
         type = HOLDS_FOLDERS; // obviously
@@ -93,13 +65,13 @@ public class NamespaceFolder extends IMAPFolder {
     }
 
     @Override
-    public Folder[] list(final String pattern) throws MessagingException {
+    public Folder[] list(String pattern) throws MessagingException {
         String fullName = this.fullName;
         char separator = getSeparator();
         final ListInfo[] li = (ListInfo[]) doCommand(new ProtocolCommand() {
 
             @Override
-            public Object doCommand(final IMAPProtocol p) throws ProtocolException {
+            public Object doCommand(IMAPProtocol p) throws ProtocolException {
                 return p.list("", new StringBuilder().append(fullName).append(separator).append(pattern).toString());
             }
         });
@@ -114,13 +86,13 @@ public class NamespaceFolder extends IMAPFolder {
     }
 
     @Override
-    public Folder[] listSubscribed(final String pattern) throws MessagingException {
+    public Folder[] listSubscribed(String pattern) throws MessagingException {
         String fullName = this.fullName;
         char separator = getSeparator();
         final ListInfo[] li = (ListInfo[]) doCommand(new ProtocolCommand() {
 
             @Override
-            public Object doCommand(final IMAPProtocol p) throws ProtocolException {
+            public Object doCommand(IMAPProtocol p) throws ProtocolException {
                 return p.lsub("", new StringBuilder().append(fullName).append(separator).append(pattern).toString());
             }
         });
@@ -134,7 +106,7 @@ public class NamespaceFolder extends IMAPFolder {
         return folders;
     }
 
-    private static final String getFullname(final ListInfo listInfo) {
+    private static final String getFullname(ListInfo listInfo) {
         String fullName = listInfo.name;
         final char separator = listInfo.separator;
         final int len = fullName.length();
@@ -151,7 +123,7 @@ public class NamespaceFolder extends IMAPFolder {
     }
 
     @Override
-    public Folder getFolder(final String name) throws MessagingException {
+    public Folder getFolder(String name) throws MessagingException {
         final Folder[] folders = list(new StringBuilder(name).append('%').toString());
         for (int i = 0; i < folders.length; i++) {
             if (folders[i].getName().equals(name)) {
@@ -162,19 +134,19 @@ public class NamespaceFolder extends IMAPFolder {
     }
 
     @Override
-    public boolean delete(final boolean recurse) throws MessagingException {
+    public boolean delete(boolean recurse) throws MessagingException {
         // Not applicable on NamespaceFolder
         throw new MethodNotSupportedException("Cannot delete Namespace Folder");
     }
 
     @Override
-    public boolean renameTo(final Folder f) throws MessagingException {
+    public boolean renameTo(Folder f) throws MessagingException {
         // Not applicable on NamespaceFolder
         throw new MethodNotSupportedException("Cannot rename Namespace Folder");
     }
 
     @Override
-    public void appendMessages(final Message[] msgs) throws MessagingException {
+    public void appendMessages(Message[] msgs) throws MessagingException {
         // Not applicable on NamespaceFolder
         throw new MethodNotSupportedException("Cannot append to Namespace Folder");
     }
