@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -75,7 +47,7 @@ final class ACLExtensionAutoDetector {
      * @param imapConfig The IMAP configuration
      * @return The IMAP server's ACL extension.
      */
-    public static ACLExtension getACLExtension(final IMAPConfig imapConfig) {
+    public static ACLExtension getACLExtension(IMAPConfig imapConfig) {
         return parse(imapConfig.asMap(), imapConfig);
     }
 
@@ -86,13 +58,13 @@ final class ACLExtensionAutoDetector {
      * @param imapConfig The IMAP configuration
      * @return The IMAP server's ACL extension.
      */
-    public static ACLExtension getACLExtension(final Map<String, String> capabilities, final IMAPConfig imapConfig) {
+    public static ACLExtension getACLExtension(Map<String, String> capabilities, IMAPConfig imapConfig) {
         return parse(capabilities, imapConfig);
     }
 
     private static final char[] RFC4314_CARACTERS_UPPER = { 'K', 'X', 'T', 'E' };
 
-    private static ACLExtension parse(final Map<String, String> capabilities, final IMAPConfig imapConfig) {
+    private static ACLExtension parse(Map<String, String> capabilities, IMAPConfig imapConfig) {
         /*
          * Examine CAPABILITY response
          */
@@ -103,7 +75,7 @@ final class ACLExtensionAutoDetector {
         /*
          * Check if newer ACL extension is supported
          */
-        for (final String upperName : capabilities.keySet()) {
+        for (String upperName : capabilities.keySet()) {
             if (upperName.startsWith("RIGHTS=", 0)) {
                 /*
                  * Check if RIGHTS=... capability contains right characters specified in RFC4314
@@ -123,7 +95,7 @@ final class ACLExtensionAutoDetector {
 
     /*-
      *
-    private static boolean containsRFC4314Character(final String rightsCapability) {
+    private static boolean containsRFC4314Character(String rightsCapability) {
         final int fromIndex = rightsCapability.indexOf('=');
         boolean found = false;
         for (int i = 0; !found && i < RFC4314_CARACTERS_UPPER.length; i++) {
