@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -91,7 +63,7 @@ public final class NamespaceFoldersCache {
      * @return The <b>binary-sorted</b> personal namespace folders
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static String[] getPersonalNamespaces(final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static String[] getPersonalNamespaces(IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         final NamespaceFoldersCacheEntry entry = new NamespaceFoldersCacheEntry(NS_PERSONAL);
         final SessionMailCache mailCache = SessionMailCache.getInstance(session, accountId);
         mailCache.get(entry);
@@ -123,7 +95,7 @@ public final class NamespaceFoldersCache {
      * @return The personal namespace folder or <code>null</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static String getPersonalNamespace(final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static String getPersonalNamespace(IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         String[] personalNamespaces = getPersonalNamespaces(imapStore, load, session, accountId);
         return null != personalNamespaces && personalNamespaces.length != 0 ? personalNamespaces[0] : null;
     }
@@ -139,7 +111,7 @@ public final class NamespaceFoldersCache {
      * @return <code>true</code> if personal namespaces contain the specified full name; otherwise <code>false</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static boolean containedInPersonalNamespaces(final String fullname, final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static boolean containedInPersonalNamespaces(String fullname, IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         return Arrays.binarySearch(getPersonalNamespaces(imapStore, load, session, accountId), fullname) >= 0;
     }
 
@@ -153,7 +125,7 @@ public final class NamespaceFoldersCache {
      * @return The <b>binary-sorted</b> user namespace folders
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static String[] getUserNamespaces(final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static String[] getUserNamespaces(IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         final NamespaceFoldersCacheEntry entry = new NamespaceFoldersCacheEntry(NS_USER);
         final SessionMailCache mailCache = SessionMailCache.getInstance(session, accountId);
         mailCache.get(entry);
@@ -185,7 +157,7 @@ public final class NamespaceFoldersCache {
      * @return <code>true</code> if user namespaces contain the specified fullname; otherwise <code>false</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static boolean containedInUserNamespaces(final String fullname, final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static boolean containedInUserNamespaces(String fullname, IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         return Arrays.binarySearch(getUserNamespaces(imapStore, load, session, accountId), fullname) >= 0;
     }
 
@@ -200,8 +172,8 @@ public final class NamespaceFoldersCache {
      * @return <code>true</code> if provided full name starts with any of user namespaces; otherwise <code>false</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static boolean startsWithAnyOfUserNamespaces(final String fullname, final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
-        for (final String userNamespace : getUserNamespaces(imapStore, load, session, accountId)) {
+    public static boolean startsWithAnyOfUserNamespaces(String fullname, IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
+        for (String userNamespace : getUserNamespaces(imapStore, load, session, accountId)) {
             if (!isEmpty(userNamespace) && fullname.startsWith(userNamespace)) {
                 return true;
             }
@@ -219,7 +191,7 @@ public final class NamespaceFoldersCache {
      * @return The <b>binary-sorted</b> shared namespace folders
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static String[] getSharedNamespaces(final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static String[] getSharedNamespaces(IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         final NamespaceFoldersCacheEntry entry = new NamespaceFoldersCacheEntry(NS_SHARED);
         final SessionMailCache mailCache = SessionMailCache.getInstance(session, accountId);
         mailCache.get(entry);
@@ -251,7 +223,7 @@ public final class NamespaceFoldersCache {
      * @return <code>true</code> if shared namespaces contain the specified full name; otherwise <code>false</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static boolean containedInSharedNamespaces(final String fullname, final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static boolean containedInSharedNamespaces(String fullname, IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
         return Arrays.binarySearch(getSharedNamespaces(imapStore, load, session, accountId), fullname) >= 0;
     }
 
@@ -266,8 +238,8 @@ public final class NamespaceFoldersCache {
      * @return <code>true</code> if provided full name starts with any of shared namespaces; otherwise <code>false</code>
      * @throws MessagingException If <code>NAMESPACE</code> command fails
      */
-    public static boolean startsWithAnyOfSharedNamespaces(final String fullname, final IMAPStore imapStore, final boolean load, final Session session, final int accountId) throws MessagingException {
-        for (final String sharedNamespace : getSharedNamespaces(imapStore, load, session, accountId)) {
+    public static boolean startsWithAnyOfSharedNamespaces(String fullname, IMAPStore imapStore, boolean load, Session session, int accountId) throws MessagingException {
+        for (String sharedNamespace : getSharedNamespaces(imapStore, load, session, accountId)) {
             if (!isEmpty(sharedNamespace) && fullname.startsWith(sharedNamespace)) {
                 return true;
             }
@@ -310,7 +282,7 @@ public final class NamespaceFoldersCache {
         }
 
         @Override
-        public void setValue(final String[] value) {
+        public void setValue(String[] value) {
             fullnames = value;
         }
 
