@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -89,7 +61,7 @@ public final class UserFlagsCache {
      * @return <code>true</code> if user flags are supported; otherwise <code>false</code>
      * @throws MessagingException If <code>SELECT</code> command fails
      */
-    public static boolean supportsUserFlags(final IMAPFolder f, final boolean load, final Session session, final int accountId) throws MessagingException {
+    public static boolean supportsUserFlags(IMAPFolder f, boolean load, Session session, int accountId) throws MessagingException {
         final UserFlagCacheEntry entry = new UserFlagCacheEntry(CHECK_ONCE ? INBOX : f.getFullName());
         final SessionMailCache mailCache = SessionMailCache.getInstance(session, accountId);
         mailCache.get(entry);
@@ -124,7 +96,7 @@ public final class UserFlagsCache {
      * @param session The session providing the session-bound cache
      * @param accountId The account ID
      */
-    public static void removeUserFlags(final IMAPFolder f, final Session session, final int accountId) {
+    public static void removeUserFlags(IMAPFolder f, Session session, int accountId) {
         SessionMailCache.getInstance(session, accountId).remove(new UserFlagCacheEntry(f.getFullName()));
     }
 
@@ -135,7 +107,7 @@ public final class UserFlagsCache {
      * @param session The session providing the session-bound cache
      * @param accountId The account ID
      */
-    public static void removeUserFlags(final String fullName, final Session session, final int accountId) {
+    public static void removeUserFlags(String fullName, Session session, int accountId) {
         SessionMailCache.getInstance(session, accountId).remove(new UserFlagCacheEntry(fullName));
     }
 
@@ -147,7 +119,7 @@ public final class UserFlagsCache {
 
         private volatile CacheKey key;
 
-        public UserFlagCacheEntry(final String fullname) {
+        public UserFlagCacheEntry(String fullname) {
             super();
             this.fullname = fullname;
         }
@@ -171,7 +143,7 @@ public final class UserFlagsCache {
         }
 
         @Override
-        public void setValue(final Boolean value) {
+        public void setValue(Boolean value) {
             this.value = value;
         }
 
