@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -118,11 +90,11 @@ public final class IMAPNumArgSplitter {
      * @param arr - <code>int</code> array of message sequence numbers
      * @return an appropriate array of command arguments
      */
-    public static String[] split(final int[] arr) {
+    public static String[] split(int[] arr) {
         return split(new Tokenizer() {
 
             @Override
-            public String getNext(final int index) {
+            public String getNext(int index) {
                 return String.valueOf(arr[index]);
             }
         }, arr.length);
@@ -135,11 +107,11 @@ public final class IMAPNumArgSplitter {
      * @param arr - <code>long</code> array of message UIDs
      * @return an appropriate array of command arguments
      */
-    public static String[] split(final long[] arr) {
+    public static String[] split(long[] arr) {
         return split(new Tokenizer() {
 
             @Override
-            public String getNext(final int index) {
+            public String getNext(int index) {
                 return Long.toString(arr[index]);
             }
         }, arr.length);
@@ -152,11 +124,11 @@ public final class IMAPNumArgSplitter {
      * @param arr - <code>Message</code> array
      * @return an appropriate array of command arguments
      */
-    public static String[] split(final Message[] arr) {
+    public static String[] split(Message[] arr) {
         return split(new Tokenizer() {
 
             @Override
-            public String getNext(final int index) {
+            public String getNext(int index) {
                 return String.valueOf(arr[index].getMessageNumber());
             }
         }, arr.length);
@@ -173,7 +145,7 @@ public final class IMAPNumArgSplitter {
      * @param consumed The number of bytes already consumed or <code>-1</code> for default (512)
      * @return an appropriate array of command arguments
      */
-    public static String[] splitSeqNumArg(final int[] arr, final boolean keepOrder, final int consumed) {
+    public static String[] splitSeqNumArg(int[] arr, boolean keepOrder, int consumed) {
         return getSeqNumArg(arr, keepOrder, true, consumed);
     }
 
@@ -189,7 +161,7 @@ public final class IMAPNumArgSplitter {
      * @param consumed The number of bytes already consumed or <code>-1</code> for default (512)
      * @return an appropriate array of command arguments
      */
-    public static String[] getSeqNumArg(final int[] arr, final boolean keepOrder, final boolean split, final int consumed) {
+    public static String[] getSeqNumArg(int[] arr, boolean keepOrder, boolean split, int consumed) {
         final TIntList l = new TIntArrayList(arr.length);
         for (int i = 0; i < arr.length; i++) {
             final int seqNum = arr[i];
@@ -220,7 +192,7 @@ public final class IMAPNumArgSplitter {
      * @param consumed The number of bytes already consumed or <code>-1</code> for default (512)
      * @return an appropriate array of command arguments
      */
-    public static String[] splitMessageArg(final Message[] arr, final boolean keepOrder, final int consumed) {
+    public static String[] splitMessageArg(Message[] arr, boolean keepOrder, int consumed) {
         final TIntList l = new TIntArrayList(arr.length);
         for (int i = 0; i < arr.length; i++) {
             final int messageNumber = arr[i].getMessageNumber();
@@ -248,7 +220,7 @@ public final class IMAPNumArgSplitter {
      * @param consumed The number of bytes already consumed or <code>-1</code> for default (512)
      * @return an appropriate array of command arguments
      */
-    public static String[] splitUIDArg(final long[] arr, final boolean keepOrder, final int consumed) {
+    public static String[] splitUIDArg(long[] arr, boolean keepOrder, int consumed) {
         final TLongArrayList l = new TLongArrayList(arr.length);
         for (int i = 0; i < arr.length; i++) {
             final long uid = arr[i];
@@ -278,7 +250,7 @@ public final class IMAPNumArgSplitter {
      * @param numbers The list of numbers; either sequence numbers or UIDs
      * @return The number argument or an empty string if specified numbers are empty
      */
-    public static String getNumArg(final TIntList numbers) {
+    public static String getNumArg(TIntList numbers) {
         int size = numbers.size();
         if (0 == size) {
             return "";
@@ -322,7 +294,7 @@ public final class IMAPNumArgSplitter {
      * @param numbers The list of numbers; either sequence numbers or UIDs
      * @return The number argument or an empty string if specified numbers are empty
      */
-    public static String getNumArg(final TLongArrayList numbers) {
+    public static String getNumArg(TLongArrayList numbers) {
         final int size = numbers.size();
         if (0 == size) {
             return "";
@@ -354,7 +326,7 @@ public final class IMAPNumArgSplitter {
         return sb.toString();
     }
 
-    private static String[] split(final Tokenizer tokenizer, final int length) {
+    private static String[] split(Tokenizer tokenizer, int length) {
         final int initCap = (length / MAX_IMAP_COMMAND_LENGTH_WITH_DEFAULT_CONSUMED);
         final List<String> tmp = new ArrayList<String>(initCap == 0 ? 10 : initCap);
         final StringBuilder sb = new StringBuilder(MAX_IMAP_COMMAND_LENGTH_WITH_DEFAULT_CONSUMED);
@@ -373,7 +345,7 @@ public final class IMAPNumArgSplitter {
         return tmp.toArray(new String[tmp.size()]);
     }
 
-    private static String[] split(final String numArg, final int maxLen) {
+    private static String[] split(String numArg, int maxLen) {
         final int len = numArg.length();
         if (len <= maxLen) {
             if (len == 0) {
