@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/fetchRespIndex.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -93,7 +65,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
      * @param destFolderName - the destination folder fullname
      * @throws MessagingException If a messaging error occurs
      */
-    public MoveIMAPCommand(final IMAPFolder imapFolder, final int startSeqNum, final int endSeqNum, final String destFolderName) throws MessagingException {
+    public MoveIMAPCommand(IMAPFolder imapFolder, int startSeqNum, int endSeqNum, String destFolderName) throws MessagingException {
         this(imapFolder, startend2long(startSeqNum, endSeqNum), destFolderName, true, true, false);
     }
 
@@ -107,7 +79,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
      * @param isSequential - whether sequence numbers are sequential or not
      * @throws MessagingException If a messaging error occurs
      */
-    public MoveIMAPCommand(final IMAPFolder imapFolder, final int[] seqNums, final String destFolderName, final boolean isSequential) throws MessagingException {
+    public MoveIMAPCommand(IMAPFolder imapFolder, int[] seqNums, String destFolderName, boolean isSequential) throws MessagingException {
         this(imapFolder, int2long(seqNums), destFolderName, isSequential, true, false);
     }
 
@@ -121,7 +93,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
      * @param fast - <code>true</code> to ignore corresponding UIDs of copied messages and return value is empty (array of length zero)
      * @throws MessagingException If a messaging error occurs
      */
-    public MoveIMAPCommand(final IMAPFolder imapFolder, final long[] uids, final String destFolderName, final boolean isSequential, final boolean fast) throws MessagingException {
+    public MoveIMAPCommand(IMAPFolder imapFolder, long[] uids, String destFolderName, boolean isSequential, boolean fast) throws MessagingException {
         this(imapFolder, uids, destFolderName, isSequential, fast, true);
     }
 
@@ -129,7 +101,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
 
     private static final int LENGTH_WITH_UID = 10; // "UID COPY <nums> <destination-folder>"
 
-    private MoveIMAPCommand(final IMAPFolder imapFolder, final long[] nums, final String destFolderName, final boolean isSequential, final boolean fast, final boolean uid) throws MessagingException {
+    private MoveIMAPCommand(IMAPFolder imapFolder, long[] nums, String destFolderName, boolean isSequential, boolean fast, boolean uid) throws MessagingException {
         super(imapFolder);
         uids = nums == null ? DEFAULT_RETVAL : nums;
         this.uid = uid;
@@ -163,7 +135,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
      * @param destFolderName - the destination folder
      * @throws MessagingException If a messaging error occurs
      */
-    public MoveIMAPCommand(final IMAPFolder imapFolder, final String destFolderName) throws MessagingException {
+    public MoveIMAPCommand(IMAPFolder imapFolder, String destFolderName) throws MessagingException {
         super(imapFolder);
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
@@ -189,7 +161,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
     }
 
     @Override
-    protected String getCommand(final int argsIndex) {
+    protected String getCommand(int argsIndex) {
         final StringBuilder sb = new StringBuilder(args[argsIndex].length() + 64);
         if (uid) {
             sb.append("UID ");
@@ -213,7 +185,7 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
     private static final String COPYUID = "copyuid";
 
     @Override
-    protected boolean handleResponse(final Response response) throws MessagingException {
+    protected boolean handleResponse(Response response) throws MessagingException {
         if (fast || !response.isOK()) {
             return false;
         }
@@ -270,14 +242,14 @@ public final class MoveIMAPCommand extends AbstractIMAPCommand<long[]> {
         return true;
     }
 
-    private static long[] startend2long(final int start, final int end) {
+    private static long[] startend2long(int start, int end) {
         final long[] longArr = new long[2];
         longArr[0] = start;
         longArr[1] = end;
         return longArr;
     }
 
-    private static long[] int2long(final int[] intArr) {
+    private static long[] int2long(int[] intArr) {
         final long[] longArr = new long[intArr.length];
         System.arraycopy(intArr, 0, longArr, 0, intArr.length);
         return longArr;
