@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -229,9 +201,8 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
      * Is called when the circuit breaker is opened: The circuit is opened and not allowing executions to occur.
      *
      * @param breakerInfo The circuit breaker that went into open state
-     * @throws Exception If an error occurs
      */
-    protected void onOpen(CircuitBreakerInfo breakerInfo) throws Exception {
+    protected void onOpen(CircuitBreakerInfo breakerInfo) {
         LOG.warn("IMAP circuit breaker opened for: {}", breakerInfo.getKey());
         breakerInfo.getMetrics().getOpensCounter().ifPresent(c -> c.increment());
     }
@@ -240,9 +211,8 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
      * Is called when the circuit breaker is half-opened: The circuit is temporarily allowing executions to occur.
      *
      * @param breakerInfo The circuit breaker that went into half-open state
-     * @throws Exception If an error occurs
      */
-    protected void onHalfOpen(CircuitBreakerInfo breakerInfo) throws Exception {
+    protected void onHalfOpen(CircuitBreakerInfo breakerInfo) {
         LOG.info("IMAP circuit breaker half-opened for: {}", breakerInfo.getKey());
     }
 
@@ -250,9 +220,8 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
      * Is called when the circuit breaker is closed: The circuit is closed and fully functional, allowing executions to occur.
      *
      * @param breakerInfo The circuit breaker that went into closed state
-     * @throws Exception If an error occurs
      */
-    protected void onClose(CircuitBreakerInfo breakerInfo) throws Exception {
+    protected void onClose(CircuitBreakerInfo breakerInfo) {
         LOG.info("IMAP circuit breaker closed for: {}", breakerInfo.getKey());
     }
 
@@ -495,16 +464,18 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
         private final String name;
         private final String host;
         private final boolean perHost;
+        private int hash;
 
         private Key(String name, String host, boolean perHost) {
             super();
             this.name = name;
             this.host = host;
             this.perHost = perHost;
+            hash = 0;
         }
 
         /**
-         * Gets the name
+         * Gets the name.
          *
          * @return The name
          */
@@ -513,7 +484,7 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
         }
 
         /**
-         * Gets the host
+         * Gets the host.
          *
          * @return The host
          */
@@ -522,7 +493,7 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
         }
 
         /**
-         * Checks if the host information denotes a certain end-point (IP address)-
+         * Checks if the host information denotes a certain end-point (IP address).
          *
          * @return <code>true</code> if a certain end-point is specified; otherwise <code>false</code>
          */
@@ -532,11 +503,15 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
 
         @Override
         public int hashCode() {
-            final int prime = 31;
-            int result = 1;
-            result = prime * result + (perHost ? 1231 : 1237);
-            result = prime * result + ((host == null) ? 0 : host.hashCode());
-            result = prime * result + ((name == null) ? 0 : name.hashCode());
+            int result = hash;
+            if (result == 0) {
+                int prime = 31;
+                result = 1;
+                result = prime * result + (perHost ? 1231 : 1237);
+                result = prime * result + ((name == null) ? 0 : name.hashCode());
+                result = prime * result + ((host == null) ? 0 : host.hashCode());
+                hash = result;
+            }
             return result;
         }
 
@@ -555,13 +530,6 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
             if (perHost != other.perHost) {
                 return false;
             }
-            if (host == null) {
-                if (other.host != null) {
-                    return false;
-                }
-            } else if (!host.equals(other.host)) {
-                return false;
-            }
             if (name == null) {
                 if (other.name != null) {
                     return false;
@@ -569,6 +537,13 @@ public abstract class AbstractFailsafeCircuitBreakerCommandExecutor implements C
             } else if (!name.equals(other.name)) {
                 return false;
             }
+            if (host == null) {
+                if (other.host != null) {
+                    return false;
+                }
+            } else if (!host.equals(other.host)) {
+                return false;
+            }
             return true;
         }
 
