@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -117,7 +89,7 @@ public final class IMAPConfig extends MailConfig {
      *
      * @param accountId The account identifier
      */
-    public IMAPConfig(final int accountId) {
+    public IMAPConfig(int accountId) {
         super();
         this.accountId = accountId;
         params = new NonBlockingHashMap<String, Object>(4);
@@ -145,7 +117,7 @@ public final class IMAPConfig extends MailConfig {
      * @param name The name
      * @param value The value
      */
-    public void setParameter(final String name, final Object value) {
+    public void setParameter(String name, Object value) {
         if (null == value) {
             params.remove(name);
         } else {
@@ -160,7 +132,7 @@ public final class IMAPConfig extends MailConfig {
      * @param clazz The parameter's type
      * @return The value
      */
-    public <V> V getParameter(final String name, final Class<? extends V> clazz) {
+    public <V> V getParameter(String name, Class<? extends V> clazz) {
         return clazz.cast(params.get(name));
     }
 
@@ -215,7 +187,7 @@ public final class IMAPConfig extends MailConfig {
     }
 
     @Override
-    public void setPort(final int imapPort) {
+    public void setPort(int imapPort) {
         this.imapPort = imapPort;
     }
 
@@ -230,7 +202,7 @@ public final class IMAPConfig extends MailConfig {
     }
 
     @Override
-    public void setServer(final String imapServer) {
+    public void setServer(String imapServer) {
         this.imapServer = null == imapServer ? null : IDNA.toUnicode(imapServer);
     }
 
@@ -242,7 +214,7 @@ public final class IMAPConfig extends MailConfig {
      * @throws OXException If IMAP capabilities cannot be initialized
      */
     @SuppressWarnings("unchecked")
-    public void initializeCapabilities(final IMAPStore imapStore, final Session session) throws OXException {
+    public void initializeCapabilities(IMAPStore imapStore, Session session) throws OXException {
         if (imapCapabilities == null) {
             synchronized (this) {
                 this.imapStore = imapStore;
@@ -317,7 +289,7 @@ public final class IMAPConfig extends MailConfig {
     }
 
     @Override
-    public void setSecure(final boolean secure) {
+    public void setSecure(boolean secure) {
         this.secure = secure;
     }
 
@@ -349,7 +321,7 @@ public final class IMAPConfig extends MailConfig {
     }
 
     @Override
-    protected void parseServerURL(final UrlInfo urlInfo) throws OXException {
+    protected void parseServerURL(UrlInfo urlInfo) throws OXException {
         final URI uri;
         try {
             uri = URIParser.parse(urlInfo.getServerURL(), URIDefaults.IMAP);
@@ -404,7 +376,7 @@ public final class IMAPConfig extends MailConfig {
     }
 
     @Override
-    public void setMailProperties(final IMailProperties mailProperties) {
+    public void setMailProperties(IMailProperties mailProperties) {
         this.mailProperties = (IIMAPProperties) mailProperties;
     }
 
