@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -133,7 +105,7 @@ public final class IMAPFolderConverter {
         }
 
         @Override
-        public Object[] getArguments(final IMAPServer imapServer) throws OXException {
+        public Object[] getArguments(IMAPServer imapServer) throws OXException {
             return imapServer.getArguments(accountId, serverUrl, sessionUser, fullname, separator, otherUserNamespaces, publicNamespaces);
         }
     }
@@ -209,7 +181,7 @@ public final class IMAPFolderConverter {
      * @return An instance of <code>{@link IMAPMailFolder}</code> containing the attributes from given IMAP folder
      * @throws OXException If conversion fails
      */
-    public static IMAPMailFolder convertFolder(final IMAPFolder imapFolder, final Session session, final IMAPAccess imapAccess, final Context ctx) throws OXException {
+    public static IMAPMailFolder convertFolder(IMAPFolder imapFolder, Session session, IMAPAccess imapAccess, Context ctx) throws OXException {
         try {
             synchronized (imapFolder) {
                 final String imapFullName = imapFolder.getFullName();
@@ -486,8 +458,8 @@ public final class IMAPFolderConverter {
      * @param tmp Helper instance of <code>StringBuilder</code>
      * @return <code>true</code> if given IMAP full name starts with any of given personal/user namespaces; otherwise <code>false</code>
      */
-    public static boolean startsWithOneOf(final String imapFullName, final char sep, final String[] personalNamespaces, final String[] userNamespaces, final StringBuilder tmp) {
-        for (final String string : userNamespaces) {
+    public static boolean startsWithOneOf(String imapFullName, char sep, String[] personalNamespaces, String[] userNamespaces, StringBuilder tmp) {
+        for (String string : userNamespaces) {
             if (imapFullName.equals(string)) {
                 return true;
             }
@@ -496,7 +468,7 @@ public final class IMAPFolderConverter {
                 return true;
             }
         }
-        for (final String string : personalNamespaces) {
+        for (String string : personalNamespaces) {
             if (imapFullName.equals(string)) {
                 return true;
             }
@@ -538,7 +510,7 @@ public final class IMAPFolderConverter {
         return ownRights;
     }
 
-    private static IMAPMailFolder convertRootFolder(final DefaultFolder rootFolder, final Session session, final IMAPConfig imapConfig) throws OXException {
+    private static IMAPMailFolder convertRootFolder(DefaultFolder rootFolder, Session session, IMAPConfig imapConfig) throws OXException {
         try {
             final IMAPMailFolder mailFolder = new IMAPMailFolder();
             mailFolder.setRootFolder(true);
@@ -607,14 +579,14 @@ public final class IMAPFolderConverter {
         }
     }
 
-    private static boolean isDefaultFoldersChecked(final Session session, final int accountId) {
+    private static boolean isDefaultFoldersChecked(Session session, int accountId) {
         final Boolean b = MailSessionCache.getInstance(session).getParameter(
             accountId,
             MailSessionParameterNames.getParamDefaultFolderChecked());
         return (b != null) && b.booleanValue();
     }
 
-    private static String[] getDefaultMailFolders(final Session session, final int accountId) {
+    private static String[] getDefaultMailFolders(Session session, int accountId) {
         return MailSessionCache.getInstance(session).getParameter(accountId, MailSessionParameterNames.getParamDefaultFolderArray());
     }
 
@@ -631,7 +603,7 @@ public final class IMAPFolderConverter {
      * @throws OXException If ACLs cannot be mapped
      * @throws MessagingException If a messaging error occurs
      */
-    private static void applyACL2Permissions(final IMAPFolder imapFolder, final ListLsubEntry listEntry, final Session session, final IMAPConfig imapConfig, final MailFolder mailFolder, final Rights ownRights, final Context ctx) throws OXException, MessagingException {
+    private static void applyACL2Permissions(IMAPFolder imapFolder, ListLsubEntry listEntry, Session session, IMAPConfig imapConfig, MailFolder mailFolder, Rights ownRights, Context ctx) throws OXException, MessagingException {
         final ACL[] acls;
         try {
             final List<ACL> list = listEntry.getACLs();
@@ -695,16 +667,16 @@ public final class IMAPFolderConverter {
      *
      * @param mailFolder The mail folder containing own permission
      */
-    private static void addOwnACL(final MailFolder mailFolder) {
+    private static void addOwnACL(MailFolder mailFolder) {
         mailFolder.addPermission(mailFolder.getOwnPermission());
     }
 
-    private static boolean isUnknownEntityError(final OXException e) {
+    private static boolean isUnknownEntityError(OXException e) {
         final int code = e.getCode();
         return (e.isPrefix("ACL") && (Entity2ACLExceptionCode.RESOLVE_USER_FAILED.getNumber() == code)) || (e.isPrefix("USR") && (LdapExceptionCode.USER_NOT_FOUND.getNumber() == code));
     }
 
-    private static boolean checkForNamespaceFolder(final String fullName, final IMAPStore imapStore, final Session session, final int accountId, boolean ignoreLsub) throws MessagingException, OXException {
+    private static boolean checkForNamespaceFolder(String fullName, IMAPStore imapStore, Session session, int accountId, boolean ignoreLsub) throws MessagingException, OXException {
         /*
          * Check for namespace folder
          */
@@ -724,7 +696,7 @@ public final class IMAPFolderConverter {
                         return true;
                     }
                     final List<ListLsubEntry> children = ListLsubCache.getCachedLISTEntry(userFolders[i], accountId, imapStore, session, ignoreLsub).getChildren();
-                    for (final ListLsubEntry entry : children) {
+                    for (ListLsubEntry entry : children) {
                         if (entry.getFullName().startsWith(fullName)) {
                             return true;
                         }
@@ -750,7 +722,7 @@ public final class IMAPFolderConverter {
      * @return The unread count
      * @throws OXException If returning unread count fails
      */
-    public static int getUnreadCount(final IMAPFolder imapFolder) throws OXException {
+    public static int getUnreadCount(IMAPFolder imapFolder) throws OXException {
         try {
             final int[] status = IMAPCommandsCollection.getStatus(imapFolder);
             return status[2];
@@ -771,7 +743,7 @@ public final class IMAPFolderConverter {
      * @return The own rights
      * @throws MessagingException In case an unrecoverable exception occurs
      */
-    public static Rights getOwnRights(final IMAPFolder folder, final Session session, final IMAPConfig imapConfig) throws MessagingException {
+    public static Rights getOwnRights(IMAPFolder folder, Session session, IMAPConfig imapConfig) throws MessagingException {
         if (folder instanceof DefaultFolder) {
             return null;
         }
@@ -816,7 +788,7 @@ public final class IMAPFolderConverter {
         return retval;
     }
 
-    private static void handleCommandFailedException(final com.sun.mail.iap.CommandFailedException e, final String fullName) {
+    private static void handleCommandFailedException(com.sun.mail.iap.CommandFailedException e, String fullName) {
         final String msg = e.getMessage().toLowerCase(Locale.ENGLISH);
         if (msg.indexOf("Mailbox doesn't exist") >= 0 || msg.indexOf("Mailbox does not exist") >= 0) {
             LOG.warn(IMAPException.getFormattedMessage(IMAPException.Code.FOLDER_NOT_FOUND, fullName), e);
