@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -70,7 +42,7 @@ public abstract class Entity2ACL {
 
     private static final ConcurrentMap<String, String> GREETING_CACHE = new ConcurrentHashMap<String, String>(16, 0.9f, 1);
 
-    private static String getGreeting(final IMAPStore imapStore, final IMAPConfig imapConfig) throws MessagingException {
+    private static String getGreeting(IMAPStore imapStore, IMAPConfig imapConfig) throws MessagingException {
         String greeting = GREETING_CACHE.get(imapConfig.getServer());
         if (null == greeting) {
             final String grt = imapStore.getGreeting();
@@ -101,7 +73,7 @@ public abstract class Entity2ACL {
      * @return an instance implementing the {@link Entity2ACL} interface.
      * @throws OXException if the instance can't be created.
      */
-    public static final Entity2ACL getInstance(final IMAPConfig imapConfig) throws OXException {
+    public static final Entity2ACL getInstance(IMAPConfig imapConfig) throws OXException {
         if (instantiated && MailAccount.DEFAULT_ID == imapConfig.getAccountId()) {
             /*
              * Auto-detection is turned off, return configured implementation
@@ -128,7 +100,7 @@ public abstract class Entity2ACL {
      * @return an instance implementing the {@link Entity2ACL} interface.
      * @throws OXException If a mail error occurs
      */
-    public static final Entity2ACL getInstance(final IMAPStore imapStore, final IMAPConfig imapConfig) throws OXException {
+    public static final Entity2ACL getInstance(IMAPStore imapStore, IMAPConfig imapConfig) throws OXException {
         if (instantiated && MailAccount.DEFAULT_ID == imapConfig.getAccountId()) {
             /*
              * Auto-detection is turned off, return configured implementation
@@ -160,7 +132,7 @@ public abstract class Entity2ACL {
      *
      * @param singleton The singleton instance of {@link Entity2ACL}
      */
-    protected final static void setInstance(final Entity2ACL singleton) {
+    protected final static void setInstance(Entity2ACL singleton) {
         Entity2ACL.singleton = singleton;
         instantiated = true;
     }
@@ -182,7 +154,7 @@ public abstract class Entity2ACL {
      * @param userId The user ID
      * @return A newly created {@link UserGroupID} instance reflecting a found user.
      */
-    protected final UserGroupID getUserRetval(final int userId) {
+    protected final UserGroupID getUserRetval(int userId) {
         if (userId < 0) {
             return UserGroupID.NULL;
         }
@@ -210,6 +182,6 @@ public abstract class Entity2ACL {
      *         {@link UserGroupID#NULL} if none found.
      * @throws OXException If user/group search fails
      */
-    public abstract UserGroupID getEntityID(final String pattern, Context ctx, Entity2ACLArgs args) throws OXException;
+    public abstract UserGroupID getEntityID(String pattern, Context ctx, Entity2ACLArgs args) throws OXException;
 
 }
