@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -116,7 +88,7 @@ public final class Entity2ACLAutoDetector {
      * @throws IOException - if an I/O error occurs
      * @throws OXException - if a server greeting could not be mapped to a supported IMAP server
      */
-    public static Entity2ACL getEntity2ACLImpl(final IMAPConfig imapConfig) throws IOException, OXException {
+    public static Entity2ACL getEntity2ACLImpl(IMAPConfig imapConfig) throws IOException, OXException {
         final String key = new StringBuilder(36).append(IDNA.toASCII(imapConfig.getServer())).append(':').append(imapConfig.getPort()).toString();
         Future<Entity2ACL> cached = map.get(key);
         if (null == cached) {
@@ -158,7 +130,7 @@ public final class Entity2ACLAutoDetector {
         private final String serverUrl;
         private final IMAPConfig imapConfig;
 
-        public Entity2ACLCallable(final String serverUrl, final IMAPConfig imapConfig) {
+        public Entity2ACLCallable(String serverUrl, IMAPConfig imapConfig) {
             super();
             this.imapConfig = imapConfig;
             this.serverUrl = serverUrl;
@@ -181,7 +153,7 @@ public final class Entity2ACLAutoDetector {
      * @return The appropriate {@link Entity2ACL} implementation
      * @throws OXException If an error occurs
      */
-    protected static Entity2ACL implFor(final String greeting, final IMAPConfig imapConfig) throws OXException {
+    protected static Entity2ACL implFor(String greeting, IMAPConfig imapConfig) throws OXException {
         /*
          * Map greeting to a known IMAP server
          */
@@ -201,8 +173,8 @@ public final class Entity2ACLAutoDetector {
      * @return The associated {@link IMAPServer} instance
      * @throws OXException If mapping fails
      */
-    private static IMAPServer mapInfo2IMAPServer(final String info, final IMAPConfig imapConfig) throws OXException {
-        for (final IMAPServer imapServer : IMAPServer.getIMAPServers()) {
+    private static IMAPServer mapInfo2IMAPServer(String info, IMAPConfig imapConfig) throws OXException {
+        for (IMAPServer imapServer : IMAPServer.getIMAPServers()) {
             if (imapServer.matches(info)) {
                 return imapServer;
             }
