@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -74,7 +46,7 @@ public enum IMAPServer {
     }, new GreetingMatcher() {
 
         @Override
-        public boolean matches(final String greeting) {
+        public boolean matches(String greeting) {
             return toLowerCase(greeting).indexOf(toLowerCase(COURIER.getName())) >= 0;
         }
     }),
@@ -90,7 +62,7 @@ public enum IMAPServer {
     }, new GreetingMatcher() {
 
         @Override
-        public boolean matches(final String greeting) {
+        public boolean matches(String greeting) {
             return toLowerCase(greeting).indexOf(toLowerCase(CYRUS.getName())) >= 0;
         }
     }),
@@ -106,7 +78,7 @@ public enum IMAPServer {
     }, new GreetingMatcher() {
 
         @Override
-        public boolean matches(final String greeting) {
+        public boolean matches(String greeting) {
             return toLowerCase(greeting).indexOf(toLowerCase(DOVECOT.getName())) >= 0;
         }
     }),
@@ -122,7 +94,7 @@ public enum IMAPServer {
     }, new GreetingMatcher() {
 
         @Override
-        public boolean matches(final String greeting) {
+        public boolean matches(String greeting) {
             return greeting.indexOf("Sun Java(tm) System Messaging Server") >= 0;
         }
     }),
@@ -138,7 +110,7 @@ public enum IMAPServer {
     }, new GreetingMatcher() {
 
         @Override
-        public boolean matches(final String greeting) {
+        public boolean matches(String greeting) {
             return toLowerCase(greeting).indexOf(toLowerCase(MDAEMON.getName())) >= 0;
         }
     }),
@@ -150,7 +122,7 @@ public enum IMAPServer {
     private final ArgumentGenerator argumentGenerator;
     private final GreetingMatcher greetingMatcher;
 
-    private IMAPServer(final String name, final Entity2ACL impl, final ArgumentGenerator argumentGenerator, final GreetingMatcher greetingMatcher) {
+    private IMAPServer(String name, Entity2ACL impl, ArgumentGenerator argumentGenerator, GreetingMatcher greetingMatcher) {
         this.name = name;
         this.impl = impl;
         this.argumentGenerator = argumentGenerator;
@@ -197,7 +169,7 @@ public enum IMAPServer {
      * @param greeting The IMAP server greeting to check against
      * @return <code>true</code> if specified IMAP server greeting indicates the server to be this IMAP server; otherwise <code>false</code>
      */
-    public boolean matches(final String greeting) {
+    public boolean matches(String greeting) {
         return greetingMatcher.matches(greeting);
     }
 
@@ -218,8 +190,8 @@ public enum IMAPServer {
      * @param name The IMAP server name
      * @return The class name of {@link Entity2ACL} implementation or <code>null</code> if none matches.
      */
-    public static final Entity2ACL getIMAPServerImpl(final String name) {
-        for (final IMAPServer imapServer : getIMAPServers()) {
+    public static final Entity2ACL getIMAPServerImpl(String name) {
+        for (IMAPServer imapServer : getIMAPServers()) {
             if (imapServer.getName().equalsIgnoreCase(name)) {
                 return imapServer.getImpl();
             }
@@ -260,7 +232,7 @@ public enum IMAPServer {
          * @param str The string
          * @return The lower-case string
          */
-        protected final String toLowerCase(final String str) {
+        protected final String toLowerCase(String str) {
             if (null == str) {
                 return null;
             }
