@@ -1,61 +1,32 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.imap.ping;
 
 import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
+import java.io.PushbackInputStream;
 import java.net.InetSocketAddress;
 import java.net.Socket;
+import java.net.SocketTimeoutException;
 import java.util.Collections;
-import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.Callable;
@@ -64,18 +35,18 @@ import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.FutureTask;
-import java.util.regex.Pattern;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.imap.config.IIMAPProperties;
 import com.openexchange.imap.services.Services;
 import com.openexchange.imap.util.HostAndPort;
-import com.openexchange.java.BoundaryExceededException;
-import com.openexchange.java.BoundedStringBuilder;
 import com.openexchange.java.Strings;
 import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
-import com.sun.mail.util.SocketFetcher;
+import com.sun.mail.iap.ProtocolException;
+import com.sun.mail.imap.GreetingListener;
+import com.sun.mail.imap.protocol.IMAPProtocol;
+import com.sun.mail.util.MailLogger;
 
 /**
  * {@link IMAPCapabilityAndGreetingCache} - A cache for CAPABILITY and greeting from IMAP servers.
@@ -203,6 +174,7 @@ public final class IMAPCapabilityAndGreetingCache {
             map = MAP;
         }
 
+        boolean currentThreadInvokedRun = false;
         Key key = new Key(endpoint.getHost(), endpoint.getPort(), isSecure);
         Future<CapabilityAndGreeting> f = map.get(key);
         if (null == f) {
@@ -211,22 +183,39 @@ public final class IMAPCapabilityAndGreetingCache {
             if (null == f) {
                 f = ft;
                 ft.run();
+                currentThreadInvokedRun = true;
             }
         }
 
-        CapabilityAndGreeting cag = getFrom(f);
-        if (isElapsed(cag, idleTime)) {
-            FutureTask<CapabilityAndGreeting> ft = new FutureTask<CapabilityAndGreeting>(new CapabilityAndGreetingCallable(endpoint, isSecure, imapProperties, primary));
-            if (map.replace(key, f, ft)) {
-                f = ft;
-                ft.run();
-            } else {
-                f = map.get(key);
+        try {
+            CapabilityAndGreeting cag = getFrom(f);
+            if (isElapsed(cag, idleTime)) {
+                FutureTask<CapabilityAndGreeting> ft = new FutureTask<CapabilityAndGreeting>(new CapabilityAndGreetingCallable(endpoint, isSecure, imapProperties, primary));
+                if (map.replace(key, f, ft)) {
+                    f = ft;
+                    ft.run();
+                    currentThreadInvokedRun = true;
+                } else {
+                    f = map.get(key);
+                }
+                cag = getFrom(f);
             }
-            cag = getFrom(f);
-        }
 
-        return cag;
+            if (currentThreadInvokedRun) {
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug("Retrieved greeting and capabilities from {}{}Greeting: {}{}Capabilities: {}", endpoint, Strings.getLineSeparator(), cag.getGreeting(), Strings.getLineSeparator(), cag.getCapability());
+                } else {
+                    LOG.info("Retrieved greeting and capabilities from {}", endpoint);
+                }
+            }
+            return cag;
+        } catch (IOException e) {
+            if (currentThreadInvokedRun) {
+                map.remove(key);
+                LOG.warn("Failed to retrieve greeting and capabilities from {}", endpoint, e);
+            }
+            throw e;
+        }
     }
 
     private static boolean isElapsed(CapabilityAndGreeting cag, int idleTime) {
@@ -251,6 +240,9 @@ public final class IMAPCapabilityAndGreetingCache {
             if (cause instanceof IOException) {
                 throw ((IOException) cause);
             }
+            if (cause instanceof ProtocolException) {
+                throw new IOException("Encountered IMAP protocol exception", cause);
+            }
             if (cause instanceof RuntimeException) {
                 throw new IOException(e.getMessage());
             }
@@ -261,9 +253,25 @@ public final class IMAPCapabilityAndGreetingCache {
         }
     }
 
-    private static final class CapabilityAndGreetingCallable implements Callable<CapabilityAndGreeting> {
+    private static final class SimpleGreetingListener implements GreetingListener {
 
-        private static final Pattern SPLIT = Pattern.compile("\r?\n");
+        private String greeting;
+
+        SimpleGreetingListener() {
+            super();
+        }
+
+        @Override
+        public void onGreetingProcessed(String greeting, String host, int port) {
+            this.greeting = greeting;
+        }
+
+        String getGreeting() {
+            return greeting;
+        }
+    }
+
+    private static final class CapabilityAndGreetingCallable implements Callable<CapabilityAndGreeting> {
 
         private final HostAndPort endpoint;
         private final boolean isSecure;
@@ -279,151 +287,24 @@ public final class IMAPCapabilityAndGreetingCache {
         }
 
         @Override
-        public CapabilityAndGreeting call() throws IOException {
-            BoundedStringBuilder sb = new BoundedStringBuilder(512, 2048);
-            String greeting = null;
-            String capabilities = null;
-
-            Socket s = null;
+        public CapabilityAndGreeting call() throws IOException, ProtocolException {
+            SimpleGreetingListener greetingListener = new SimpleGreetingListener();
+            IMAPProtocol imapProtocol = new IMAPProtocol("imap", endpoint.getHost(), endpoint.getPort(), "test", createImapProps(greetingListener), isSecure, createLogger());
             try {
-                // Establish socket connection
-                s = SocketFetcher.getSocket(endpoint.getHost(), endpoint.getPort(), createImapProps(), "mail.imap", false);
-
-                // State variables
-                InputStream in = s.getInputStream();
-                OutputStream out = s.getOutputStream();
-                boolean skipLF = false;
-                boolean eol = false;
-
-                // Read IMAP server greeting on connect
-                if (in.available() > 0) {
-                    for (int i; !eol && ((i = in.read()) != -1);) {
-                        char c = (char) i;
-                        switch (c) {
-                            case '\r':
-                                eol = true;
-                                skipLF = true;
-                                break;
-                            case '\n':
-                                eol = true;
-                                skipLF = false;
-                                break;
-                            default:
-                                sb.append(c);
-                                break;
-                        }
-                    }
-                }
-                greeting = sb.toString();
-                sb.setLength(0);
-
-                if (skipLF) {
-                    // Consume final LF
-                    in.read();
-                    skipLF = false;
-                }
-
-                // Request capabilities through CAPABILITY command
-                out.write("A1 CAPABILITY\r\n".getBytes());
-                out.flush();
-
-                // Read CAPABILITY response
-                {
-                    boolean hasNextLine = true;
-                    while (hasNextLine) {
-                        hasNextLine = false;
-                        eol = false;
-
-                        if (skipLF) {
-                            // Consume final LF
-                            in.read();
-                            skipLF = false;
-                        }
-
-                        int i = in.read();
-                        if (i != -1) {
-                            // Character '*' (42) indicates an un-tagged response; meaning subsequent response lines will follow
-                            hasNextLine = (i == 42);
-
-                            do {
-                                char c = (char) i;
-                                switch (c) {
-                                    case '\r':
-                                        eol = true;
-                                        skipLF = true;
-                                        break;
-                                    case '\n':
-                                        eol = true;
-                                        skipLF = false;
-                                        break;
-                                    default:
-                                        sb.append(c);
-                                        break;
-                                }
-                            } while (!eol && ((i = in.read()) != -1));
-
-                            if (sb.length() >= 5 && sb.indexOf(" BYE ", 0) >= 0) {
-                                // Received "BYE" response
-                                sb.insert(0, "Received BYE response from IMAP server: ");
-                                throw new IOException(sb.toString());
-                            }
-
-                            // Append LF if a next line is expected
-                            if (hasNextLine) {
-                                sb.append('\n');
-                            }
-
-                        }
-                    }
-
-                    String[] lines = SPLIT.split(sb.toString());
-                    sb.setLength(0);
-                    for (String line : lines) {
-                        if (line.startsWith("* CAPABILITY ")) {
-                            sb.append(line.substring(12));
-                        } else if (!line.startsWith("A1 ")) {
-                            sb.append(' ').append(line);
-                        }
-                    }
-                    capabilities = sb.toString();
-                }
-
-                if (skipLF) {
-                    // Consume final LF
-                    in.read();
-                    skipLF = false;
-                }
-
-                // Close connection through LOGOUT command
-                out.write("A2 LOGOUT\r\n".getBytes());
-                out.flush();
-
-                // Create & return new CapabilityAndGreeting instance
-                LOG.debug("Successfully fetched capabilities and greeting from IMAP server \"{}\":{}{}{}{}", endpoint.getHost(), Strings.getLineSeparator(), greeting, Strings.getLineSeparator(), capabilities);
-                return new CapabilityAndGreeting(capabilities, greeting);
-            } catch (BoundaryExceededException e) {
-                if (null == greeting) {
-                    // Exceeded while reading greeting
-                    throw e;
-                }
-
-                if (null == capabilities) {
-                    // Exceeded while reading greeting
-                    capabilities = sb.toString().trim();
-                }
+                String greeting = greetingListener.getGreeting();
+                imapProtocol.capability(true);
+                Map<String, String> capabilities = imapProtocol.getCapabilities();
                 return new CapabilityAndGreeting(capabilities, greeting);
             } finally {
-                if (null != s) {
-                    try {
-                        s.close();
-                    } catch (@SuppressWarnings("unused") Exception e) {
-                        // ignore
-                    }
-                }
+                imapProtocol.disconnect();
             }
         }
 
-        private Properties createImapProps() {
+        private MailLogger createLogger() {
+            return new MailLogger(this.getClass(), "DEBUG IMAP", false, null);
+        }
+
+        private Properties createImapProps(GreetingListener greetingListener) {
             Properties imapProps = MimeDefaultSession.getDefaultMailProperties();
             {
                 int connectionTimeout = imapProperties.getImapConnectionTimeout();
@@ -464,6 +345,7 @@ public final class IMAPCapabilityAndGreetingCache {
                     imapProps.put("mail.imap.login.encoding", authenc);
                 }
             }
+            imapProps.put("mail.imap.greeting.listeners", Collections.<GreetingListener> singletonList(greetingListener));
             return imapProps;
         }
 
@@ -500,31 +382,54 @@ public final class IMAPCapabilityAndGreetingCache {
         return new InetSocketAddress(endpoint.getHost(), port);
     }
 
+    static ReadResult tryRead(PushbackInputStream in, Socket s) throws IOException {
+        int newTimeout = 5000;
+        int prevTimeout = s.getSoTimeout();
+        if (prevTimeout <= newTimeout) {
+            return tryRead(in);
+        }
+
+        s.setSoTimeout(newTimeout);
+        try {
+            return tryRead(in);
+        } finally {
+            // Restore timeout
+            s.setSoTimeout(prevTimeout);
+        }
+    }
+
+    private static ReadResult tryRead(PushbackInputStream in) throws IOException {
+        try {
+            int read = in.read();
+            if (read == -1) {
+                return ReadResult.END_OF_STREAM;
+            }
+            // Push byte back to stream & signal available byte
+            in.unread(read);
+            return ReadResult.BYTE_AVAILABLE;
+        } catch (SocketTimeoutException e) {
+            return ReadResult.NO_DATA;
+        }
+    }
+
+    private static enum ReadResult {
+        BYTE_AVAILABLE, END_OF_STREAM, NO_DATA;
+    }
+
+    // -------------------------------------------------------------------------------------------------------------------------------------
+
     /**
      * The capabilities & greeting information for an IMAP server (URL).
      */
     public static final class CapabilityAndGreeting {
 
-        private static final Pattern SPLIT = Pattern.compile(" +");
-
         private final Map<String, String> capabilities;
         private final String greeting;
         private final long stamp;
 
-        CapabilityAndGreeting(String capability, String greeting) {
+        CapabilityAndGreeting(Map<String, String> capabilities, String greeting) {
             super();
-            if (null == capability) {
-                capabilities = Collections.emptyMap();
-            } else {
-                String[] caps = SPLIT.split(capability);
-                Map<String, String> capabilities = new LinkedHashMap<String, String>(caps.length);
-                for (String cap : caps) {
-                    if (Strings.isNotEmpty(cap)) {
-                        capabilities.put(Strings.toUpperCase(cap), cap);
-                    }
-                }
-                this.capabilities = Collections.unmodifiableMap(capabilities);
-            }
+            this.capabilities = capabilities;
             this.greeting = greeting;
             this.stamp = System.currentTimeMillis();
         }
@@ -561,7 +466,7 @@ public final class IMAPCapabilityAndGreetingCache {
         }
 
         @Override
-        public boolean equals(final Object obj) {
+        public boolean equals(Object obj) {
             if (this == obj) {
                 return true;
             }
