@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -251,7 +223,7 @@ public final class IMAPSort {
      * @param descendingDirection The order direction
      * @return The sort criteria ready for being used inside IMAP's <i>SORT</i> command or <code>null</code> if sort field is not supported by IMAP
      */
-    public static String getSortCritForIMAPCommand(final MailSortField sortField, final boolean descendingDirection) {
+    public static String getSortCritForIMAPCommand(MailSortField sortField, boolean descendingDirection) {
         final StringBuilder imapSortCritBuilder = new StringBuilder(16).append(descendingDirection ? "REVERSE " : "");
         switch (sortField) {
         case SENT_DATE:
@@ -475,7 +447,7 @@ public final class IMAPSort {
      * @return The partial result
      * @throws MessagingException If ESORT fails
      */
-    public static SortPartialResult sortReturnPartial(final SortTerm[] sortTerms, final javax.mail.search.SearchTerm jmsSearchTerm, IndexRange indexRange, IMAPFolder imapFolder) throws MessagingException {
+    public static SortPartialResult sortReturnPartial(SortTerm[] sortTerms, javax.mail.search.SearchTerm jmsSearchTerm, IndexRange indexRange, IMAPFolder imapFolder) throws MessagingException {
         try {
             final String atom = new StringBuilder(16).append(indexRange.start + 1).append(':').append(indexRange.end).toString();
             return (SortPartialResult) imapFolder.doCommand(new ProtocolCommand() {
@@ -595,7 +567,7 @@ public final class IMAPSort {
         }
     }
 
-    private static int[] sort(final SortTerm[] sortTerms, final javax.mail.search.SearchTerm jmsSearchTerm, IMAPFolder imapFolder, boolean fallbackOnCommandFailed) throws MessagingException, OXException {
+    private static int[] sort(SortTerm[] sortTerms, javax.mail.search.SearchTerm jmsSearchTerm, IMAPFolder imapFolder, boolean fallbackOnCommandFailed) throws MessagingException, OXException {
         try {
             return (int[]) imapFolder.doCommand(new ProtocolCommand() {
 
@@ -702,7 +674,7 @@ public final class IMAPSort {
      * @return The sorted UIDs or <code>null</code> if needed capabilities aren't supported
      * @throws MessagingException If a messaging error occurs
      */
-    public static long[] allUIDs(final IMAPFolder imapFolder, final boolean descending, final IMAPConfig imapConfig) throws MessagingException {
+    public static long[] allUIDs(IMAPFolder imapFolder, boolean descending, IMAPConfig imapConfig) throws MessagingException {
         if (imapFolder.getMessageCount() <= 0) {
             /*
              * Empty folder...
@@ -727,13 +699,13 @@ public final class IMAPSort {
         private final boolean descending;
         private final IMAPFolder imapFolder;
 
-        public SORTProtocolCommand(final boolean descending, IMAPFolder imapFolder) {
+        public SORTProtocolCommand(boolean descending, IMAPFolder imapFolder) {
             this.descending = descending;
             this.imapFolder = imapFolder;
         }
 
         @Override
-        public Object doCommand(final IMAPProtocol p) throws ProtocolException {
+        public Object doCommand(IMAPProtocol p) throws ProtocolException {
             final String command = new StringBuilder("UID SORT (").append(descending ? "REVERSE " : "").append("ARRIVAL) UTF-8 ALL").toString();
             final Response[] r = IMAPCommandsCollection.performCommand(p, command);
             final Response response = r[r.length - 1];
