@@ -1,54 +1,28 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.imap.storecache;
 
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.locks.LockSupport;
 import javax.mail.MessagingException;
 import com.openexchange.session.Session;
 import com.sun.mail.imap.IMAPStore;
@@ -78,7 +52,7 @@ public final class BoundaryAwareIMAPStoreContainer extends UnboundedIMAPStoreCon
      *
      * @return The limiter
      */
-    private Limiter getLimiter(final int max) {
+    private Limiter getLimiter(int max) {
         Limiter tmp = limiter;
         if (null == tmp) {
             synchronized (this) {
@@ -107,24 +81,42 @@ public final class BoundaryAwareIMAPStoreContainer extends UnboundedIMAPStoreCon
         }
 
         // Await until permit is available
-        int count = maxRetryCount;
+        boolean acquired = false;
         synchronized (limiter) {
-            while (count-- > 0 && !limiter.acquire()) {
+            int retryCount = 0;
+            do {
                 LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): W A I T I N G -- {}", limiter);
-                limiter.wait(2000);
-            }
+                exponentialBackoffWait(++retryCount, 1000L); // Exponential back-off
+                acquired = limiter.acquire();
+            } while (retryCount < maxRetryCount && !acquired);
         }
-        if (count <= 0) {
+        
+        // Check if acquired
+        if (acquired) {
+            LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- {}", limiter);
+        } else {
             // Timed out -- So what...?
             LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): T I M E D   O U T -- {}", limiter);
             // /final String message = "Max. number of connections exceeded. Try again later.";
             // /throw new MessagingException(message, new com.sun.mail.iap.ConnectQuotaExceededException(message));
         }
-
-        LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- {}", limiter);
         return super.getStore(imapSession, login, pw, session);
     }
 
+    /**
+     * Performs a wait according to exponential back-off strategy.
+     * <pre>
+     * (retry-count * base-millis) + random-millis
+     * </pre>
+     *
+     * @param retryCount The current number of retries
+     * @param baseMillis The base milliseconds
+     */
+    private static void exponentialBackoffWait(int retryCount, long baseMillis) {
+        long nanosToWait = TimeUnit.NANOSECONDS.convert((retryCount * baseMillis) + ((long) (Math.random() * baseMillis)), TimeUnit.MILLISECONDS);
+        LockSupport.parkNanos(nanosToWait);
+    }
+
     @Override
     public void backStore(IMAPStore imapStore) {
         try {
