@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -137,7 +109,7 @@ public final class IMAPStoreCache {
 
             @SuppressWarnings("synthetic-access")
             @Override
-            public void reloadConfiguration(final ConfigurationService configService) {
+            public void reloadConfiguration(ConfigurationService configService) {
                 SHRINKER_MILLIS.set(configService.getIntProperty("com.openexchange.mail.mailAccessCacheShrinkerSeconds", 3) * 1000);
                 IDLE_MILLIS.set(configService.getIntProperty("com.openexchange.mail.mailAccessCacheIdleSeconds", 4) * 1000);
                 IMAPStoreCache tmp = instance;
@@ -275,7 +247,7 @@ public final class IMAPStoreCache {
     public void dropFor(int userId, int contextId) {
         final Queue<Key> keyQueue = keys.remove(UserAndContext.newInstance(userId, contextId));
         if (null != keyQueue) {
-            for (final Key key : keyQueue) {
+            for (Key key : keyQueue) {
                 final IMAPStoreContainer container = map.remove(key);
                 if (null != container) {
                     container.clear();
@@ -439,8 +411,8 @@ public final class IMAPStoreCache {
 
     // -------------------------------------------------------------------------------------------------------------------------------------
 
-    private static Key newKey(int accountId, String host, int port, String user, int userId, int contextId) {
-        return new Key(accountId, host, port, user, userId, contextId);
+    private static Key newKey(int accountId, String host, int port, String login, int userId, int contextId) {
+        return new Key(accountId, host, port, login, userId, contextId);
     }
 
     /**
@@ -451,17 +423,17 @@ public final class IMAPStoreCache {
         private final int accountId;
         private final String host;
         private final int port;
-        private final String user;
+        private final String login;
         final int userId;
         final int contextId;
         private final int hash;
 
-        Key(int accountId, String host, int port, String user, int userId, int contextId) {
+        Key(int accountId, String host, int port, String login, int userId, int contextId) {
             super();
             this.accountId = accountId;
             this.host = host;
             this.port = port;
-            this.user = user;
+            this.login = login;
             this.userId = userId;
             this.contextId = contextId;
             final int prime = 31;
@@ -469,7 +441,7 @@ public final class IMAPStoreCache {
             result = prime * result + accountId;
             result = prime * result + ((host == null) ? 0 : host.hashCode());
             result = prime * result + port;
-            result = prime * result + ((user == null) ? 0 : user.hashCode());
+            result = prime * result + ((login == null) ? 0 : login.hashCode());
             result = prime * result + userId;
             result = prime * result + contextId;
             hash = result;
@@ -481,7 +453,7 @@ public final class IMAPStoreCache {
         }
 
         @Override
-        public boolean equals(final Object obj) {
+        public boolean equals(Object obj) {
             if (this == obj) {
                 return true;
             }
@@ -508,16 +480,15 @@ public final class IMAPStoreCache {
             } else if (!host.equals(other.host)) {
                 return false;
             }
-            if (user == null) {
-                if (other.user != null) {
+            if (login == null) {
+                if (other.login != null) {
                     return false;
                 }
-            } else if (!user.equals(other.user)) {
+            } else if (!login.equals(other.login)) {
                 return false;
             }
             return true;
         }
-
-    }
+    } // End of class Key
 
 }
