@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -67,7 +39,6 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.session.Session;
 import com.sun.mail.imap.GreetingListener;
 import com.sun.mail.imap.IMAPStore;
-import com.sun.mail.util.PropUtil;
 
 /**
  * {@link UnboundedIMAPStoreContainer} - The unbounded {@link IMAPStoreContainer}.
@@ -101,16 +72,8 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
         this.checkConnectivityIfPolled = checkConnectivityIfPolled;
     }
 
-    private void checkMaxNumConnections(javax.mail.Session imapSession, Session session) {
-        int maxNumAuthenticated = PropUtil.getIntProperty(imapSession.getProperties(), "mail.imap.maxNumAuthenticated", 0);
-        if (maxNumAuthenticated > 0) {
-            LOG.warn("Property \"com.openexchange.imap.storeContainerType\" is set to \"unbounded\", but \"com.openexchange.imap.maxNumConnections\" is greater than 0 (zero) for user {} in context {}. Please review settings.", I(session.getUserId()), I(session.getContextId()));
-        }
-    }
-
     @Override
     public IMAPStore getStore(javax.mail.Session imapSession, String login, String pw, Session session) throws IMAPStoreContainerInvalidException, MessagingException, InterruptedException {
-        checkMaxNumConnections(imapSession, session);
         // Poll or create IMAP store
         IMAPStoreWrapper imapStoreWrapper;
         lock.lock();
@@ -134,10 +97,9 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
         // Polled an existing instance
         IMAPStore imapStore = imapStoreWrapper.imapStore;
 
-        if (checkConnectivityIfPolled && (false == imapStore.isConnected())) {
-            // IMAPStore instance is no more connected
-            final IMAPStore imapStore1 = imapStore;
-            IMAPAccess.closeSafely(imapStore1);
+        if ((checkConnectivityIfPolled && (false == imapStore.isConnected())) || (imapSession.getDebug() != imapStore.getDebug())) {
+            // IMAPStore instance is no more connected OR debug flag does not match
+            IMAPAccess.closeSafely(imapStore);
             imapStore = newStore(server, port, login, pw, imapSession, session);
             LOG.debug("UnboundedIMAPStoreContainer.getStore(): Returning newly established IMAP store instance. {} -- {}", imapStore.toString(), I(imapStore.hashCode()));
             return imapStore;
@@ -168,7 +130,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
     }
 
     @Override
-    public void backStore(final IMAPStore imapStore) {
+    public void backStore(IMAPStore imapStore) {
         // Try to put back given IMAP store w/o validity check
         boolean enqueued;
         lock.lock();
@@ -195,7 +157,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
     }
 
     @Override
-    public void closeElapsed(final long stamp) {
+    public void closeElapsed(long stamp) {
         LOG.debug("IMAPStoreContainer.closeElapsed(): Closing elapsed IMAP store instances from queue for {}:{}", server, I(port));
 
         List<IMAPStoreWrapper> wrappersToClose = new ArrayList<>();
@@ -293,12 +255,12 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
         }
 
         @Override
-        public boolean add(final IMAPStoreWrapper e) {
+        public boolean add(IMAPStoreWrapper e) {
             return offer(e);
         }
 
         @Override
-        public boolean offer(final IMAPStoreWrapper e) {
+        public boolean offer(IMAPStoreWrapper e) {
             return q.offer(e);
         }
 
@@ -309,7 +271,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
          * @param minTimeStamp The minimum time stamp; any queued entry that has a last-accessed time stamp lower than given one is considered as elapsed
          * @return The elapsed head of this queue
          */
-        public IMAPStoreWrapper pollIfElapsed(final long minTimeStamp) {
+        public IMAPStoreWrapper pollIfElapsed(long minTimeStamp) {
             final IMAPStoreWrapper e = q.peek();
             if ((null != e) && (e.lastAccessed < minTimeStamp)) {
                 return q.poll();
@@ -333,12 +295,12 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
         }
 
         @Override
-        public boolean remove(final Object o) {
+        public boolean remove(Object o) {
             return q.remove(o);
         }
 
         @Override
-        public boolean contains(final Object o) {
+        public boolean contains(Object o) {
             return q.contains(o);
         }
 
@@ -358,7 +320,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
         }
 
         @Override
-        public <T> T[] toArray(final T[] a) {
+        public <T> T[] toArray(T[] a) {
             return q.toArray(a);
         }
 
@@ -378,7 +340,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
 
             int lastRet; // index of last element, or -1 if no such
 
-            Itr(final Object[] array) {
+            Itr(Object[] array) {
                 lastRet = -1;
                 this.array = array;
             }
@@ -406,7 +368,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
                 lastRet = -1;
                 // Traverse underlying queue to find == element,
                 // not just a .equals element.
-                for (final Iterator<IMAPStoreWrapper> it = q.iterator(); it.hasNext();) {
+                for (Iterator<IMAPStoreWrapper> it = q.iterator(); it.hasNext();) {
                     if (it.next() == x) {
                         it.remove();
                         return;
@@ -415,7 +377,7 @@ public class UnboundedIMAPStoreContainer extends AbstractIMAPStoreContainer {
             }
         }
 
-        private void writeObject(final java.io.ObjectOutputStream s) throws java.io.IOException {
+        private void writeObject(java.io.ObjectOutputStream s) throws java.io.IOException {
             s.defaultWriteObject();
         }
 
