@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -117,7 +89,7 @@ public final class ThreadableMapping {
 
     } // End of class MessageKey
 
-    private static MessageKey keyFor(final MailMessage mailMessage) {
+    private static MessageKey keyFor(MailMessage mailMessage) {
         if (null == mailMessage) {
             return null;
         }
@@ -130,7 +102,7 @@ public final class ThreadableMapping {
     /**
      * Initializes a new {@link ThreadableMapping}.
      */
-    public ThreadableMapping(final int capacity) {
+    public ThreadableMapping(int capacity) {
         super();
         refsMap = new HashMap<String, List<MailMessage>>(capacity << 1, 0.9f);
         messageIdMap = new HashMap<String, List<MailMessage>>(capacity, 0.9f);
@@ -143,7 +115,7 @@ public final class ThreadableMapping {
      * @param thread The thread to add into
      * @return Whether <code>thread</code> has been changed as a result of this call
      */
-    public boolean checkFor(final Iterable<MailMessage> toCheck, final List<MailMessage> thread) {
+    public boolean checkFor(Iterable<MailMessage> toCheck, List<MailMessage> thread) {
         boolean changed = false;
         // Set for existing Message-Ids
         final Set<String> existingMessageIds = new HashSet<String>(thread.size());
@@ -152,13 +124,13 @@ public final class ThreadableMapping {
         }
         // Set for already processed ones
         final Set<MessageKey> processed = new HashSet<MessageKey>(thread.size());
-        for (final MailMessage mail : toCheck) {
+        for (MailMessage mail : toCheck) {
             final String messageId = mail.getMessageId();
             if (null != messageId) {
                 // Those mails that refer to specified mail
                 final List<MailMessage> referencees = refsMap.get(messageId);
                 if (null != referencees) {
-                    for (final MailMessage candidate : referencees) {
+                    for (MailMessage candidate : referencees) {
                         if (!existingMessageIds.contains(candidate.getMessageId()) && processed.add(keyFor(candidate))) {
                             thread.add(candidate);
                             changed = true;
@@ -172,7 +144,7 @@ public final class ThreadableMapping {
                 // Those mails that are referenced by specified mail
                 final List<MailMessage> references = messageIdMap.get(inReplyTo);
                 if (null != references) {
-                    for (final MailMessage candidate : references) {
+                    for (MailMessage candidate : references) {
                         if (processed.add(keyFor(candidate))) {
                             thread.add(candidate);
                             changed = true;
@@ -183,11 +155,11 @@ public final class ThreadableMapping {
             */
             final String[] sReferences = mail.getReferences();
             if (null != sReferences) {
-                for (final String sReference : sReferences) {
+                for (String sReference : sReferences) {
                     // Those mails that are referenced by specified mail
                     final List<MailMessage> references = messageIdMap.get(sReference);
                     if (null != references) {
-                        for (final MailMessage candidate : references) {
+                        for (MailMessage candidate : references) {
                             if (!existingMessageIds.contains(candidate.getMessageId()) && processed.add(keyFor(candidate))) {
                                 thread.add(candidate);
                                 changed = true;
@@ -206,7 +178,7 @@ public final class ThreadableMapping {
      * @param messageId The <code>Message-Id</code> header
      * @return The {@code MailMessage} instances
      */
-    public Set<MailMessage> getRefs(final String messageId) {
+    public Set<MailMessage> getRefs(String messageId) {
         final List<MailMessage> list = refsMap.get(messageId);
         return list == null ? Collections.<MailMessage> emptySet() : new LinkedHashSet<MailMessage>(list);
     }
@@ -217,7 +189,7 @@ public final class ThreadableMapping {
      * @param messageId The <code>Message-Id</code> header
      * @return The {@code MailMessage} instances
      */
-    public Set<MailMessage> getMessageId(final String messageId) {
+    public Set<MailMessage> getMessageId(String messageId) {
         final List<MailMessage> list = messageIdMap.get(messageId);
         return list == null ? Collections.<MailMessage> emptySet() : new LinkedHashSet<MailMessage>(list);
     }
@@ -228,17 +200,17 @@ public final class ThreadableMapping {
      * @param mails The {@code MailMessage} instances
      * @return This mapping
      */
-    public ThreadableMapping initWith(final List<MailMessage> mails) {
+    public ThreadableMapping initWith(List<MailMessage> mails) {
         fill(mails, messageIdMap, refsMap);
         return this;
     }
 
-    private static void fill(final List<MailMessage> mails, final Map<String, List<MailMessage>> messageIdMap, final Map<String, List<MailMessage>> refsMap) {
+    private static void fill(List<MailMessage> mails, Map<String, List<MailMessage>> messageIdMap, Map<String, List<MailMessage>> refsMap) {
         final String hdrMessageId = MessageHeaders.HDR_MESSAGE_ID;
-        for (final MailMessage current : mails) {
+        for (MailMessage current : mails) {
             final String[] refs = current.getReferences();
             if (null != refs) {
-                for (final String reference : refs) {
+                for (String reference : refs) {
                     if (!com.openexchange.java.Strings.isEmpty(reference)) {
                         List<MailMessage> list = refsMap.get(reference);
                         if (null == list) {
