@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -115,14 +87,14 @@ public class Threader {
      *
      * @param threadableRoot The start of the list.
      */
-    public Threadable thread(final Threadable threadableRoot) {
+    public Threadable thread(Threadable threadableRoot) {
         if (threadableRoot == null) {
             return null;
         }
 
         idMap = new HashMap<String, ThreadContainer>();
 
-        for (final Enumeration<Threadable> e = threadableRoot.allElements(); e.hasMoreElements();) {
+        for (Enumeration<Threadable> e = threadableRoot.allElements(); e.hasMoreElements();) {
             final Threadable t = e.nextElement();
             if (!t.isDummy()) {
                 buildContainer(t);
@@ -174,7 +146,7 @@ public class Threader {
      *
      * @param threadable The {@code Threadable} instance to build container for
      */
-    private void buildContainer(final Threadable threadable) {
+    private void buildContainer(Threadable threadable) {
         String id = threadable.messageID();
         ThreadContainer container = idMap.get(id);
 
@@ -296,7 +268,7 @@ public class Threader {
     private ThreadContainer findRootSet() {
         final ThreadContainer root = new ThreadContainer();
         // root.debug_id = "((root))";
-        for (final ThreadContainer c : idMap.values()) {
+        for (ThreadContainer c : idMap.values()) {
             if (c.parent == null) {
                 if (c.next != null) {
                     throw new RuntimeException("c.next is " + c.next.toString());
@@ -315,7 +287,7 @@ public class Threader {
      *
      * @param parent The parent container
      */
-    private void pruneEmptyContainers(final ThreadContainer parent) {
+    private void pruneEmptyContainers(ThreadContainer parent) {
         ThreadContainer container, prev, next;
         for (prev = null, container = parent.child, next = container.next; container != null; prev = container, container = next, next =
             (container == null ? null : container.next)) {
@@ -408,6 +380,7 @@ public class Threader {
      * <p>
      * This is so that messages which don't have <code>References</code> headers at all still get threaded (to the extent possible, at least.)
      */
+    @SuppressWarnings("null")
     private void gatherSubjects() {
         int count = 0;
         for (ThreadContainer c = rootNode.child; c != null; c = c.next) {
