@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -166,7 +138,7 @@ public final class Conversations {
      * @param byEnvelope <code>true</code> to use ENVELOPE fetch item; other <code>false</code> to use single headers (<i>"References"</i>, <i>"In-Reply-To"</i>, and <i>"Message-Id"</i>)
      * @return The fetch profile ready for building up conversations
      */
-    public static FetchProfile checkFetchProfile(final FetchProfile fetchProfile, final boolean byEnvelope) {
+    public static FetchProfile checkFetchProfile(FetchProfile fetchProfile, boolean byEnvelope) {
         // Add 'References' to FetchProfile if absent
         {
             String hdrReferences = MessageHeaders.HDR_REFERENCES;
@@ -213,7 +185,7 @@ public final class Conversations {
             return Collections.<Conversation> emptyList();
         }
         final List<Conversation> conversations = new ArrayList<Conversation>(messages.size());
-        for (final MailMessage message : messages) {
+        for (MailMessage message : messages) {
             conversations.add(new Conversation(message));
         }
         return conversations;
@@ -234,7 +206,7 @@ public final class Conversations {
      * @throws MessagingException If a messaging error occurs
      */
     @SuppressWarnings("unchecked")
-    public static List<MailMessage> messagesFor(final IMAPFolder imapFolder, final int lookAhead, final OrderDirection order, final FetchProfile fetchProfile, final IMAPServerInfo serverInfo, final boolean byEnvelope, final boolean examineHasAttachmentUserFlags, final boolean previewSupported) throws MessagingException {
+    public static List<MailMessage> messagesFor(IMAPFolder imapFolder, int lookAhead, OrderDirection order, FetchProfile fetchProfile, IMAPServerInfo serverInfo, boolean byEnvelope, boolean examineHasAttachmentUserFlags, boolean previewSupported) throws MessagingException {
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             /*
@@ -247,7 +219,7 @@ public final class Conversations {
         return (List<MailMessage>) (imapFolder.doCommand(new IMAPFolder.ProtocolCommand() {
 
             @Override
-            public Object doCommand(final IMAPProtocol protocol) throws ProtocolException {
+            public Object doCommand(IMAPProtocol protocol) throws ProtocolException {
                 // Compile command
                 final List<MailMessage> mails;
                 final String command;
@@ -343,12 +315,12 @@ public final class Conversations {
      * @param conversations The conversations to transform
      * @return The resulting list of <tt>ThreadSortNode</tt>s
      */
-    public static List<ThreadSortNode> toNodeList(final List<Conversation> conversations) {
+    public static List<ThreadSortNode> toNodeList(List<Conversation> conversations) {
         if (null == conversations) {
             return Collections.emptyList();
         }
         final List<ThreadSortNode> list = new ArrayList<ThreadSortNode>(conversations.size());
-        for (final Conversation conversation : conversations) {
+        for (Conversation conversation : conversations) {
             final List<MailMessage> messages = conversation.getMessages();
             final ThreadSortNode root = toThreadSortNode((IDMailMessage) messages.remove(0));
             root.addChildren(toThreadSortNodes(messages));
@@ -357,13 +329,13 @@ public final class Conversations {
         return list;
     }
 
-    private static ThreadSortNode toThreadSortNode(final IDMailMessage message) {
+    private static ThreadSortNode toThreadSortNode(IDMailMessage message) {
         return new ThreadSortNode(new MessageInfo(message.getSeqnum()).setFullName(message.getFolder()), message.getUid());
     }
 
-    private static List<ThreadSortNode> toThreadSortNodes(final List<MailMessage> messages) {
+    private static List<ThreadSortNode> toThreadSortNodes(List<MailMessage> messages) {
         final List<ThreadSortNode> ret = new ArrayList<ThreadSortNode>(messages.size());
-        for (final MailMessage message : messages) {
+        for (MailMessage message : messages) {
             ret.add(toThreadSortNode((IDMailMessage) message));
         }
         return ret;
@@ -375,12 +347,12 @@ public final class Conversations {
      * @param toFold The conversations to fold
      * @return The folded conversations
      */
-    public static List<Conversation> fold(final List<Conversation> toFold) {
+    public static List<Conversation> fold(List<Conversation> toFold) {
         fold(toFold, null);
         return toFold;
     }
 
-    private static void fold(final List<Conversation> toFold, Map<String, Conversation> lookupTable) {
+    private static void fold(List<Conversation> toFold, Map<String, Conversation> lookupTable) {
         // first collect a temporal lookup table and fold for the first time
         {
             Map<String, Conversation> tempLookupTable = new HashMap<String, Conversation>(toFold.size());
@@ -456,7 +428,7 @@ public final class Conversations {
      * @param toMergeWith The List of MaillMessages to be added
      * @return The folded conversations
      */
-    public static List<Conversation> foldAndMergeWithList(final List<Conversation> toFold, List<MailMessage> toMergeWith) {
+    public static List<Conversation> foldAndMergeWithList(List<Conversation> toFold, List<MailMessage> toMergeWith) {
         HashMap<String, Conversation> lookupTable = new HashMap<String, Conversation>(toFold.size() * 2);
         fold(toFold, lookupTable);
         for (MailMessage mailMessage : toMergeWith) {
