@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -79,9 +51,9 @@ public final class MessageInfo {
      * @param messageIds The message identifiers
      * @return The message numbers
      */
-    public static TIntList toSeqNums(final Collection<MessageInfo> messageIds) {
+    public static TIntList toSeqNums(Collection<MessageInfo> messageIds) {
         final TIntList ret = new TIntArrayList(messageIds.size());
-        for (final MessageInfo messageId : messageIds) {
+        for (MessageInfo messageId : messageIds) {
             ret.add(messageId.messageNumber);
         }
         return ret;
@@ -93,10 +65,10 @@ public final class MessageInfo {
      * @param messageIds The message identifiers
      * @return The message numbers
      */
-    public static int[] toSeqNumsArray(final Collection<MessageInfo> messageIds) {
+    public static int[] toSeqNumsArray(Collection<MessageInfo> messageIds) {
         final int[] ret = new int[messageIds.size()];
         int i = 0;
-        for (final MessageInfo messageId : messageIds) {
+        for (MessageInfo messageId : messageIds) {
             ret[i++] = messageId.messageNumber;
         }
         return ret;
@@ -108,7 +80,7 @@ public final class MessageInfo {
      * @param msgId The message idenfifier's string representation
      * @return The message identifier
      */
-    public static MessageInfo valueOf(final String msgId) {
+    public static MessageInfo valueOf(String msgId) {
         return valueOf(msgId, 0, msgId.length());
     }
 
@@ -118,7 +90,7 @@ public final class MessageInfo {
      * @param msgId The message idenfifier's string representation
      * @return The message identifier
      */
-    public static MessageInfo valueOf(final String msgId, final int off, final int len) {
+    public static MessageInfo valueOf(String msgId, int off, int len) {
         if (com.openexchange.java.Strings.isEmpty(msgId)) {
             return null;
         }
@@ -161,7 +133,7 @@ public final class MessageInfo {
      *
      * @param messageNumber The message number
      */
-    public MessageInfo(final int messageNumber) {
+    public MessageInfo(int messageNumber) {
         super();
         this.messageNumber = messageNumber;
         accountId = -1;
@@ -183,7 +155,7 @@ public final class MessageInfo {
      * @param slen The <code>slen</code> to set
      * @return This message identifier
      */
-    public MessageInfo setSlen(final int slen) {
+    public MessageInfo setSlen(int slen) {
         this.slen = slen;
         return this;
     }
@@ -203,7 +175,7 @@ public final class MessageInfo {
      * @param messageNumber The message number to set
      * @return This message identifier
      */
-    public MessageInfo setMessageNumber(final int messageNumber) {
+    public MessageInfo setMessageNumber(int messageNumber) {
         this.messageNumber = messageNumber;
         return this;
     }
@@ -223,7 +195,7 @@ public final class MessageInfo {
      * @param fullName The full name to set
      * @return This message identifier
      */
-    public MessageInfo setFullName(final String fullName) {
+    public MessageInfo setFullName(String fullName) {
         this.fullName = fullName;
         return this;
     }
@@ -243,7 +215,7 @@ public final class MessageInfo {
      * @param accountId The account identifier to set
      * @return This message identifier
      */
-    public MessageInfo setAccountId(final int accountId) {
+    public MessageInfo setAccountId(int accountId) {
         this.accountId = accountId;
         return this;
     }
@@ -273,7 +245,7 @@ public final class MessageInfo {
     }
 
     @Override
-    public boolean equals(final Object obj) {
+    public boolean equals(Object obj) {
         if (this == obj) {
             return true;
         }
