@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -65,16 +37,14 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.folderstorage.Folder;
 import com.openexchange.imap.IMAPCommandsCollection;
 import com.openexchange.imap.IMAPFolderStorage;
 import com.openexchange.imap.services.Services;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
 import com.openexchange.mail.FullnameArgument;
-import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.api.IMailFolderStorage;
-import com.openexchange.mail.api.IMailFolderStorageDelegator;
 import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.mime.MimeMailException;
@@ -138,9 +108,10 @@ public class ExtAccountFolderField implements AdditionalFolderField {
                         mailAccess.connect();
                     }
                 }
+                final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess1 = mailAccess;
 
 
-                folderStorage = getImapFolderStorage(mailAccess);
+                folderStorage = com.openexchange.imap.IMAPAccess.getIMAPFolderStorageFrom(mailAccess1);
                 IMAPStore imapStore = folderStorage.getImapStore();
                 Map<String, FolderInfo> folders = getExternalAccountFolders((IMAPFolder) imapStore.getDefaultFolder());
                 if (null == folders) {
@@ -167,8 +138,8 @@ public class ExtAccountFolderField implements AdditionalFolderField {
     }
 
     @Override
-    public Object getValue(FolderObject folder, ServerSession session) {
-        String fullName = folder.getFullName();
+    public Object getValue(Folder folder, ServerSession session) {
+        String fullName = folder.getID();
         if (Strings.isEmpty(fullName)) {
             return JSONObject.NULL;
         }
@@ -213,7 +184,7 @@ public class ExtAccountFolderField implements AdditionalFolderField {
     }
 
     @Override
-    public List<Object> getValues(List<FolderObject> folder, ServerSession session) {
+    public List<Object> getValues(List<Folder> folder, ServerSession session) {
         return AdditionalFieldsUtils.bulk(this, folder, session);
     }
 
@@ -241,27 +212,6 @@ public class ExtAccountFolderField implements AdditionalFolderField {
         }
     }
 
-    /**
-     * Get the IMP folder storage from the specified mail access
-     *
-     * @param mailAccess
-     * @return
-     * @throws OXException
-     */
-    private IMAPFolderStorage getImapFolderStorage(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws OXException {
-        IMailFolderStorage fstore = mailAccess.getFolderStorage();
-        if (!(fstore instanceof IMAPFolderStorage)) {
-            if (!(fstore instanceof IMailFolderStorageDelegator)) {
-                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
-            }
-            fstore = ((IMailFolderStorageDelegator) fstore).getDelegateFolderStorage();
-            if (!(fstore instanceof IMAPFolderStorage)) {
-                throw MailExceptionCode.UNEXPECTED_ERROR.create("Unknown MAL implementation");
-            }
-        }
-        return (IMAPFolderStorage) fstore;
-    }
-
     /**
      * Get the external account folders
      *
@@ -269,7 +219,7 @@ public class ExtAccountFolderField implements AdditionalFolderField {
      * @return
      * @throws OXException
      */
-    private Map<String, FolderInfo> getExternalAccountFolders(final IMAPFolder imapFolder) throws OXException {
+    private Map<String, FolderInfo> getExternalAccountFolders(IMAPFolder imapFolder) throws OXException {
         try {
             final Map<String, FolderInfo> results = new HashMap<String, FolderInfo>(8);
             imapFolder.doCommand(new IMAPFolder.ProtocolCommand() {
