@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -79,7 +51,7 @@ public final class IMAPSessionStorageAccess {
         return ENABLED;
     }
 
-    private static IMAPSessionStorage ensureExistence(final Session session) {
+    private static IMAPSessionStorage ensureExistence(Session session) {
         return new IMAPSessionStorage(session);
     }
 
@@ -91,7 +63,7 @@ public final class IMAPSessionStorageAccess {
      * @param session The session providing user data
      * @return <code>true</code> if session storage contains entries for given folder; otherwise <code>false</code>
      */
-    public static boolean hasSessionStorage(final int accountId, final IMAPFolder imapFolder, final Session session) {
+    public static boolean hasSessionStorage(int accountId, IMAPFolder imapFolder, Session session) {
         if (!ENABLED) {
             return true;
         }
@@ -106,7 +78,7 @@ public final class IMAPSessionStorageAccess {
      * @param session The session providing user data
      * @throws OXException If a mail error occurs
      */
-    public static void fillSessionStorage(final int accountId, final IMAPFolder imapFolder, final Session session) throws OXException {
+    public static void fillSessionStorage(int accountId, IMAPFolder imapFolder, Session session) throws OXException {
         if (!ENABLED) {
             return;
         }
@@ -124,7 +96,7 @@ public final class IMAPSessionStorageAccess {
      * @return The IMAP messages of which flags have been changed since specified time stamp
      * @throws OXException If a mail error occurs
      */
-    public static long[][] getChanges(final int accountId, final IMAPFolder imapFolder, final Session session, final int mode) throws OXException {
+    public static long[][] getChanges(int accountId, IMAPFolder imapFolder, Session session, int mode) throws OXException {
         if (!ENABLED) {
             return new long[][] { new long[] {}, new long[] {} };
         }
@@ -140,7 +112,7 @@ public final class IMAPSessionStorageAccess {
      * @param fullName The IMAP folder's full name
      * @throws OXException If an error occurs while deleting UIDs
      */
-    public static void removeDeletedSessionData(final long[] deletedUIDs, final int accountId, final Session session, final String fullName) {
+    public static void removeDeletedSessionData(long[] deletedUIDs, int accountId, Session session, String fullName) {
         if (!ENABLED) {
             return;
         }
@@ -156,7 +128,7 @@ public final class IMAPSessionStorageAccess {
      * @param fullName The IMAP folder's full name
      * @throws OXException If an error occurs while deleting UIDs
      */
-    public static void removeDeletedSessionData(final Set<Long> deletedUIDs, final int accountId, final Session session, final String fullName) {
+    public static void removeDeletedSessionData(Set<Long> deletedUIDs, int accountId, Session session, String fullName) {
         if (!ENABLED) {
             return;
         }
@@ -171,7 +143,7 @@ public final class IMAPSessionStorageAccess {
      * @param fullName The IMAP folder's full name
      * @throws OXException If an error occurs while deleting UIDs
      */
-    public static void removeDeletedFolder(final int accountId, final Session session, final String fullName) {
+    public static void removeDeletedFolder(int accountId, Session session, String fullName) {
         if (!ENABLED) {
             return;
         }
